@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Calendario",
-    "To-dos" : "Tareas",
+    "Tasks" : "Tareas",
     "Personal" : "Personal",
     "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
     "You created calendar {calendar}" : "Usted creó el calendario {calendar}",
@@ -15,7 +15,7 @@ OC.L10N.register(
     "You shared calendar {calendar} as public link" : "Has compartido el calendario {calendar} con un enlace público",
     "You removed public link for calendar {calendar}" : "Has eliminado el enlace público al calendario {calendar}",
     "{actor} shared calendar {calendar} with you" : "{actor} compartió el calendario {calendar} con usted",
-    "You shared calendar {calendar} with {user}" : "Usted compartió el calendario {calendar} con {usuario}",
+    "You shared calendar {calendar} with {user}" : "Usted compartió el calendario {calendar} con {user}",
     "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
     "{actor} unshared calendar {calendar} from you" : "{actor} dejó de compartir el calendario {calendar} con usted",
     "You unshared calendar {calendar} from {user}" : "Usted dejó de compartir el calendario {calendar} de {user}",
@@ -55,6 +55,7 @@ OC.L10N.register(
     "A calendar <strong>to-do</strong> was modified" : "Se ha modificado una <strong>tarea</strong> de calendario",
     "Contact birthdays" : "Cumpleaños del contacto",
     "Death of %s" : "Muerte de %s",
+    "Untitled calendar" : "Calendario sin título",
     "Calendar:" : "Calendario:",
     "Date:" : "Fecha:",
     "Where:" : "Dónde:",
@@ -71,25 +72,71 @@ OC.L10N.register(
     "Description: %s" : "Descripción: %s",
     "Where: %s" : "Lugar: %s",
     "%1$s via %2$s" : "%1$s vía %2$s",
+    "In a %1$s on %2$s for the entire day" : "En un(a) %1$s el %2$s todo el día",
+    "In a %1$s on %2$s between %3$s - %4$s" : "En un(a) %1$s el %2$s entre las %3$s - %4$s",
+    "In %1$s %2$s on %3$s for the entire day" : "En %1$s %2$s el %3$s todo el día",
+    "In %1$s %2$s on %3$s between %4$s - %5$s" : "En %1$s %2$s el %3$s entre las %4$s - %5$s",
+    "Could not generate when statement" : "No se ha podido general la declaración de cuándo",
+    "Every Day for the entire day" : "Todos los días durante todo el día",
+    "Every Day for the entire day until %1$s" : "Cada day todo el día hasta el %1$s",
+    "Every Day between %1$s - %2$s" : "Todos los días entre %1$s - %2$s",
+    "Every Day between %1$s - %2$s until %3$s" : "Todos los días entre %1$s - %2$s hasta %3$s",
+    "Every %1$d Days for the entire day" : "Cada %1$d días todo el día",
+    "Every %1$d Days for the entire day until %2$s" : "Cada %1$d días todo el día hasta el %2$s",
+    "Every %1$d Days between %2$s - %3$s" : "Cada %1$d días entre las %2$s y %3$s",
+    "Every %1$d Days between %2$s - %3$s until %4$s" : "Cada %1$d días entre las %2$s y %3$s hasta el %4$s",
+    "Could not generate event recurrence statement" : "No se ha podido generar la declaración de recurrencia",
+    "Every Week on %1$s for the entire day" : "Cada semana el %1$s todo el día",
+    "Every Week on %1$s for the entire day until %2$s" : "Cada %1$s días todo el día hasta el %2$s",
+    "Every Week on %1$s between %2$s - %3$s" : "Cada semana el %1$s entre %2$s y %3$s",
+    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Cada semana el %1$s entre %2$s y %3$s hasta el %4$s",
+    "Every %1$d Weeks on %2$s for the entire day" : "Cada %1$d semanas el %2$s todo el día",
     "Cancelled: %1$s" : "Cancelado: %1$s",
-    "Invitation canceled" : "Invitación cancelada",
+    "\"%1$s\" has been canceled" : "\"%1$s\" ha sido cancelada",
     "Re: %1$s" : "Re: %1$s",
-    "Invitation updated" : "Invitación actualizada",
+    "%1$s has accepted your invitation" : "%1$s ha aceptado su invitación",
+    "%1$s has tentatively accepted your invitation" : "%1$s ha aceptado su invitación de forma tentativa",
+    "%1$s has declined your invitation" : "%1$s ha rechazado su invitación",
+    "%1$s has responded to your invitation" : "%1$s ha respondido a su invitación",
+    "Invitation updated: %1$s" : "Invitación actualizada: %1$s",
+    "%1$s updated the event \"%2$s\"" : "%1$s actualizó el evento \"%2$s\"",
     "Invitation: %1$s" : "Invitación: %1$s",
-    "Invitation" : "Invitación",
-    "Title:" : "Título:",
-    "Time:" : "Hora:",
-    "Location:" : "Ubicación:",
-    "Link:" : "Enlace:",
+    "%1$s would like to invite you to \"%2$s\"" : "%1$s desea invitarle a \"%2$s\"",
     "Organizer:" : "Organizador:",
     "Attendees:" : "Asistentes:",
+    "Title:" : "Título:",
+    "When:" : "Cuándo:",
+    "Location:" : "Ubicación:",
+    "Link:" : "Enlace:",
     "Accept" : "Aceptar",
     "Decline" : "Rechazar",
     "More options …" : "Más opciones...",
     "More options at %s" : "Más opciones en %s",
+    "Monday" : "Lunes",
+    "Tuesday" : "Martes",
+    "Wednesday" : "Miércoles",
+    "Thursday" : "Jueves",
+    "Friday" : "Viernes",
+    "Saturday" : "Sábado",
+    "Sunday" : "Domingo",
+    "January" : "Enero",
+    "February" : "Febrero",
+    "March" : "Marzo",
+    "April" : "Abril",
+    "May" : "Mayo",
+    "June" : "Junio",
+    "July" : "Julio",
+    "August" : "Agosto",
+    "September" : "Septiembre",
+    "October" : "Octubre",
+    "November" : "Noviembre",
+    "December" : "Diciembre",
+    "First" : "Primera",
+    "Second" : "Segundo",
+    "Last" : "Última",
     "Contacts" : "Contactos",
     "{actor} created address book {addressbook}" : "{actor} ha creado la libreta de direcciones {addressbook}",
-    "You created address book {addressbook}" : "Has creado la libreta de direcciones {adressbook}",
+    "You created address book {addressbook}" : "Has creado la libreta de direcciones {addressbook}",
     "{actor} deleted address book {addressbook}" : "{actor} ha eliminado la libreta de direcciones {addressbook}",
     "You deleted address book {addressbook}" : "Has eliminado la libreta de direcciones {addressbook}",
     "{actor} updated address book {addressbook}" : "{actor} ha actualizado la libreta de direcciones {addressbook}",
@@ -112,6 +159,8 @@ OC.L10N.register(
     "{actor} updated contact {card} in address book {addressbook}" : "{actor} ha actualizado el contacto {card} en la libreta de direcciones {addressbook}",
     "You updated contact {card} in address book {addressbook}" : "Has actualizado el contacto {card} en la libreta de direcciones {addressbook}",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Se ha modificado un <strong>contacto</strong> o una  <strong>libreta de direcciones</strong> ",
+    "Accounts" : "Cuentas",
+    "System address book which holds all accounts" : "Libretas de direcciones del sistema que contienen todas las cuentas",
     "File is not updatable: %1$s" : "El archivo no se puede actualizar: %1$s",
     "Could not write to final file, canceled by hook" : "No se pudo escribir en el archivo final, cancelado por el sistema.",
     "Could not write file contents" : "No se han podido escribir los contenidos del archivo",
@@ -121,12 +170,9 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "No se pudo escribir en el archivo final, cancelado por el sistema.",
     "Could not rename part file to final file" : "No se ha podido renombrar el archivo parcial como el archivo final",
     "Failed to check file size: %1$s" : "Fallo al comprobar el tamaño del archivo: %1$s",
-    "Could not open file" : "No se ha podido abrir el archivo",
     "Encryption not ready: %1$s" : "El cifrado no está listo: %1$s",
     "Failed to open file: %1$s" : "Fallo al abrir el archivo: %1$s",
     "Failed to unlink: %1$s" : "Fallo al desenlazar: %1$s",
-    "Invalid chunk name" : "Nombre de trozo inválido",
-    "Could not rename part file assembled from chunks" : "No se ha podido renombrar el archivo parcial formado por los fragmentos",
     "Failed to write file contents: %1$s" : "Fallo al escribir el contenido del archivo: %1$s",
     "File not found: %1$s" : "Archivo no encontrado: %1$s",
     "System is in maintenance mode." : "Sistema está en modo de mantenimiento.",
@@ -135,65 +181,69 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Configura una cuenta CalDAV",
     "Configures a CardDAV account" : "Configura una cuenta CardDAV",
     "Events" : "Eventos",
-    "Tasks" : "Tareas",
     "Untitled task" : "Tarea sin título",
     "Completed on %s" : "Completado el %s",
     "Due on %s by %s" : "Finaliza el %s por %s",
     "Due on %s" : "Finaliza el %s",
+    "DAV system address book" : "Libreta de direcciónes DAV del sistema",
+    "No outstanding DAV system address book sync." : "No hay una sincronización pendiente en la libreta de direcciones DAV del sistema.",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "La sincronización DAV de la libreta de direcciones del sistema no se ha ejecutado ya que su instancia tiene más de 1000 usuarios o por que ha ocurrido un error. Por favor, ejecútela manualmente llamando al comando: \"occ dav:sync-system-addressbook\".",
+    "WebDAV endpoint" : "Endpoint WebDAV",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "No se pudo verificar si su servidor web está adecuadamente configurado para permitir la sincronización de archivos a través de WebDAV. Por favor, verifique manualmente.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Tu servidor web todavía no está configurado correctamente para permitir la sincronización de archivos, porque la interfaz WebDAV parece estar rota.",
+    "Your web server is properly set up to allow file synchronization over WebDAV." : "Su servidor web está adecuadamente configurado para permitir la sincronización de archivos a través de WebDAV.",
     "Migrated calendar (%1$s)" : "Calendario migrado (%1$s)",
     "Calendars including events, details and attendees" : "Calendarios que incluyen eventos, detalles y asistentes",
     "Contacts and groups" : "Contactos y grupos",
     "WebDAV" : "WebDAV",
-    "WebDAV endpoint" : "Extremo de WebDAV",
-    "Availability" : "Disponibilidad",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Si configura su horario de trabajo, otros usuarios verán cuándo está fuera de la oficina cuando planifiquen una reunión.",
+    "First day" : "Primer día",
+    "Last day (inclusive)" : "Último día (incluido)",
+    "Short absence status" : "Estado de ausencia corta",
+    "Long absence Message" : "Mensaje en ausencia larga",
+    "Save" : "Guardar",
+    "Disable absence" : "Deshabilitar ausencia",
+    "Absence saved" : "Ausencia guardada",
+    "Failed to save your absence settings" : "Error al guardar tus ajustes de ausencia",
+    "Absence cleared" : "Ausencia limpiada",
+    "Failed to clear your absence settings" : "Error al borrar tus ajustes de ausencia",
     "Time zone:" : "Zona horaria:",
     "to" : "para",
     "Delete slot" : "Eliminar espacio",
     "No working hours set" : "No se han establecido horas de funcionamiento",
     "Add slot" : "Añadir espacio",
-    "Monday" : "Lunes",
-    "Tuesday" : "Martes",
-    "Wednesday" : "Miércoles",
-    "Thursday" : "Jueves",
-    "Friday" : "Viernes",
-    "Saturday" : "Sábado",
-    "Sunday" : "Domingo",
+    "Weekdays" : "Días de semana",
+    "Pick a start time for {dayName}" : "Elija una hora de inicio para {dayName}",
+    "Pick a end time for {dayName}" : "Elija una hora fin para {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Cambiar automáticamente el estado del usuario a \"No molestar\" cuando no esté disponible para silenciar todas las notificaciones.",
-    "Save" : "Guardar",
     "Failed to load availability" : "No se ha podido cargar la disponibilidad",
     "Saved availability" : "Disponibilidad guardada",
     "Failed to save availability" : "No se ha podido guardar la disponibilidad",
+    "Availability" : "Disponibilidad",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si configura sus horas laborales, otras personas verán cuando está fuera de la oficina cuando agenden una reunión.",
+    "Absence" : "Ausencia",
+    "Configure your next absence period." : "Configura el siguiente periodo en que estarás ausente",
     "Calendar server" : "Servidor de calendario",
     "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
     "Automatically generate a birthday calendar" : "Generar automáticamente un calendario de cumpleaños",
     "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños se generarán mediante un trabajo en segundo plano.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Por ello, no estarán disponibles inmediatamente tras activarlos, sino que aparecerán después de cierto tiempo.",
     "Send notifications for events" : "Enviar notificaciones de los eventos",
-    "Notifications are sent via background jobs, so these must occur often enough." : "Las notificaciones son enviadas a través de trabajos en segundo plano, por lo que estos deben ocurrir con la suficiente frecuencia.",
+    "Notifications are sent via background jobs, so these must occur often enough." : "Las notificaciones son enviadas a través de trabajos en segundo plano, por lo que estos deben ocurrir con suficiente frecuencia.",
     "Send reminder notifications to calendar sharees as well" : "Enviar recordatorio también a los usuarios con los que se comparte el calendario",
-    "Reminders are always sent to organizers and attendees." : "Los recordatorios siempre se envía a los organizadores y asistentes.",
+    "Reminders are always sent to organizers and attendees." : "Los recordatorios siempre se envían a los organizadores y asistentes.",
     "Enable notifications for events via push" : "Activar notificaciones push para eventos",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instala también la {calendarappstoreopen}app de Calendario{linkclose} o {calendardocopen}conecta tu escritorio y móvil para sincronizar ↗{linkclose}.",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Por favor, asegúrate de configurar correctamente {emailopen}el servidor web{linkclose}",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instale también la {calendarappstoreopen}app de Calendario{linkclose} o {calendardocopen}conecte su escritorio y móvil para sincronizar ↗{linkclose}.",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Por favor, asegúrese de configurar correctamente {emailopen}el servidor web{linkclose}",
     "There was an error updating your attendance status." : "Ha habido un error al actualizar tu estado de asistencia.",
     "Please contact the organizer directly." : "Por favor, contacta directamente con el organizador.",
     "Are you accepting the invitation?" : "¿Aceptas la invitación?",
     "Tentative" : "Provisional",
-    "Number of guests" : "Número de invitados",
-    "Comment" : "Comentario",
     "Your attendance was updated successfully." : "Tu asistencia se ha actualizado con éxito.",
-    "Todos" : "Todos",
-    "{actor} created todo {todo} in list {calendar}" : "{actor} creó la tarea {todo} en la lista {calendar}",
-    "You created todo {todo} in list {calendar}" : "Usted creó la tarea {todo} en la lista {calendar}",
-    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminó la tarea {todo} de la lista {calendar}",
-    "You deleted todo {todo} from list {calendar}" : "Usted eliminó la tarea {tod} de la lista {calendar}",
-    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó la tarea {todo }en la lista {calendar}",
-    "You updated todo {todo} in list {calendar}" : "Usted actualizó la tarea {todo} en la lista {calendar}",
-    "{actor} solved todo {todo} in list {calendar}" : "{actor} completó la tarea {todo} en la lista {calendar}",
-    "You solved todo {todo} in list {calendar}" : "Usted completó la tarea {todo} en la lista {calendar}",
-    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió la tarea {todo} en la lista {calendar}",
-    "You reopened todo {todo} in list {calendar}" : "Usted reabrió la tarea {todo} en la lista {calendar}",
-    "A calendar <strong>todo</strong> was modified" : "Una <strong>lista de tareas</strong> fue modificada"
+    "To-dos" : "Tareas",
+    "Time:" : "Hora:",
+    "Could not open file" : "No se ha podido abrir el archivo",
+    "Invalid chunk name" : "Nombre de trozo inválido",
+    "Could not rename part file assembled from chunks" : "No se ha podido renombrar el archivo parcial formado por los fragmentos",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Si configura su horario de trabajo, otros usuarios verán cuándo está fuera de la oficina cuando planifiquen una reunión."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
