@@ -1,120 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "Datei konnte nicht gefunden werden",
-    "Move or copy" : "Verschieben oder kopieren",
-    "Download" : "Herunterladen",
-    "Delete" : "Löschen",
-    "Tags" : "Schlagworte",
-    "Show list view" : "Listenansicht anzeigen",
-    "Show grid view" : "Rasteransicht anzeigen",
-    "Home" : "Home",
-    "Close" : "Schließen",
-    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
-    "This will stop your current uploads." : "Hiermit werden die aktuellen Uploads angehalten.",
-    "Upload cancelled." : "Hochladen abgebrochen.",
-    "Processing files …" : "Dateien werden verarbeitet …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, du möchtest{size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
-    "Target folder \"{dir}\" does not exist any more" : "Ziel-Verzeichnis \"{dir}\" existiert nicht mehr",
-    "Not enough free space" : "Nicht genügend freier Speicherplatz",
-    "An unknown error has occurred" : "Es ist ein unbekannter Fehler aufgetreten",
-    "File could not be uploaded" : "Datei konnte nicht hochgeladen werden.",
-    "Uploading …" : "Lade hoch …",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Lade hoch … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Hochladen von Daten dieser Art wird nicht unterstützt.",
-    "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
-    "Operation is blocked by access control" : "Vorgang wird durch die Zugangskontrolle blockiert",
-    "Error when assembling chunks, status code {status}" : "Fehler beim Zusammenführen der Teile (Chunks), Fehlermeldung {status}",
-    "Actions" : "Aktionen",
-    "Rename" : "Umbenennen",
-    "Move" : "Verschieben",
-    "Copy" : "Kopieren",
-    "Choose target folder" : "Zielordner wählen",
-    "Set reminder" : "Erinnerung erstellen",
-    "Edit locally" : "Lokal bearbeiten",
-    "Open" : "Öffnen",
-    "Delete file" : "Datei löschen",
-    "Delete folder" : "Ordner löschen",
-    "Disconnect storage" : "Speicher trennen",
-    "Leave this share" : "Diese Freigabe verlassen",
-    "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
-    "Files" : "Dateien",
-    "Details" : "Details",
-    "Please select tag(s) to add to the selection" : "Bitte wähle das/die Schlagwort(e) aus, das/die du zur Auswahl hinzufügen möchtest",
-    "Apply tag(s) to selection" : "Schlagwort(e) auf die Auswahl anwenden",
-    "Select directory \"{dirName}\"" : "Verzeichnis \"{dirName}\" auswählen",
-    "Select file \"{fileName}\"" : "Datei \"{fileName}\" auswählen",
-    "Pending" : "Ausstehend",
-    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
-    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder den Administrator kontaktieren.",
-    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
-    "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
-    "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
-    "copy" : "Kopie",
-    "Could not copy \"{file}\", target exists" : "\"{file}\" konnte nicht kopiert werden, Ziel existiert bereits",
-    "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
-    "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
-    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
-    "{newName} already exists" : "{newName} existiert bereits",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei \"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte einen anderen Namen verwenden.",
-    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
-    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert.",
-    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner \"{dir}\" konnte nicht erstellt werden, da dieser bereits existiert",
-    "Could not fetch file details \"{file}\"" : "Details zu \"{file}\" konnten nicht ermittelt werden",
-    "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Gib mehr als zwei Zeichen ein, um in anderen Ordnern zu suchen.",
-    "Name" : "Name",
-    "Size" : "Größe",
-    "Modified" : "Geändert",
-    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
-    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
-    "{dirs} and {files}" : "{dirs} und {files}",
-    "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
-    "You do not have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
-    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
-    "New" : "Neu",
-    "New file/folder menu" : "Menü für neue Datei/Ordner",
-    "Select file range" : "Dateibereich auswählen",
-    "{used}%" : "{used}%",
-    "{used} of {quota} used" : "{used} von {quota} verwendet",
-    "{used} used" : "{used} verwendet",
-    "\"{name}\" is an invalid file name." : "„{name}“ ist kein gültiger Dateiname.",
-    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
-    "\"/\" is not allowed inside a file name." : "\"/\" ist innerhalb eines Dateinamens nicht erlaubt.",
-    "\"{name}\" is not an allowed filetype" : "„{name}“ ist kein erlaubter Dateityp",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppenordner \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externer Speicher \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppenordner \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externer Speicher \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Dein Speicher ist beinahe voll ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
-    "View in folder" : "In Ordner anzeigen",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
-    "Path" : "Pfad",
-    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
-    "Favorited" : "Favorisiert",
-    "Favorite" : "Favorit",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Direktlink kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
-    "New folder" : "Neuer Ordner",
-    "Create new folder" : "Neuen Ordner erstellen",
-    "Upload file" : "Datei hochladen",
-    "Recent" : "Neueste",
-    "Not favorited" : "Nicht favorisiert",
-    "Remove from favorites" : "Von Favoriten entfernen",
-    "Add to favorites" : "Zu den Favoriten hinzufügen",
-    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
     "Added to favorites" : "Zu den Favoriten hinzugefügt",
     "Removed from favorites" : "Aus den Favoriten entfernt",
     "You added {file} to your favorites" : "Du hast {file} zu deinen Favoriten hinzugefügt",
@@ -154,22 +40,19 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Du hast {oldfile} nach {newfile} verschoben",
     "{user} moved {oldfile} to {newfile}" : "{user} hat {oldfile} nach {newfile} verschoben",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Eine Datei wurde deinen <strong>Favoriten</strong> hinzugefügt oder daraus entfernt",
+    "Files" : "Dateien",
     "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Eine favorisierte Datei oder ein Ordner wurde <strong>geändert</strong>",
     "Failed to authorize" : "Autorisierung fehlgeschlagen",
     "Invalid folder path" : "Ungültiger Order-Pfad",
     "Folder not found" : "Ordner nicht gefunden",
     "Upload (max. %s)" : "Hochladen (max. %s)",
-    "Files compatibility" : "Dateikompatibilität",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ermöglicht die Einschränkung von Dateinamen, um sicherzustellen, dass Dateien mit allen Clients synchronisiert werden können. Standardmäßig sind alle unter POSIX (z. B. Linux oder macOS) gültigen Dateinamen zulässig.",
-    "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
     "Accept" : "Akzeptieren",
     "Reject" : "Ablehnen",
     "Incoming ownership transfer from {user}" : "Eingehende Besitzübertragung von {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Soll {path} angenommen werden?\n\nInfo: Der Übertragungsprozess nach der Annahme kann bis zu einer Stunde dauern.",
     "Ownership transfer denied" : "Besitzübertragung verweigert",
-    "Your ownership transfer of {path} was denied by {user}." : "Die Eigentumsübertragung von {path} wurde von {user} abgelehnt.",
+    "Your ownership transfer of {path} was denied by {user}." : "Die Besitzübertragung von {path} wurde von {user} abgelehnt.",
     "Ownership transfer failed" : "Besitzübertragung fehlgeschlagen",
     "Your ownership transfer of {path} to {user} failed." : "Die Besitzübertragung von {path} an {user} ist fehlgeschlagen.",
     "The ownership transfer of {path} from {user} failed." : "Die Übertragung von {path} ist fehlgeschlagen.",
@@ -178,17 +61,26 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
     "in %s" : "in %s",
     "Transferred from %1$s on %2$s" : "Übertragen von %1$s auf %2$s",
+    "Files compatibility" : "Dateikompatibilität",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Ermöglicht die Einschränkung von Dateinamen, um sicherzustellen, dass Dateien mit allen Clients synchronisiert werden können. Standardmäßig sind alle unter POSIX (z. B. Linux oder macOS) gültigen Dateinamen zulässig.",
+    "Enforce Windows compatibility" : "Windows-Kompatibilität erzwingen",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Dadurch werden Dateinamen blockiert, die auf Windows-Systemen unzulässig sind, z. B. reservierte Namen oder Sonderzeichen. Die Kompatibilität der Groß-/Kleinschreibung wird dadurch jedoch nicht erzwungen.",
     "File Management" : "Dateiverwaltung",
     "Current directory path" : "Aktueller Verzeichnispfad",
+    "Home" : "Home",
+    "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
     "Reload current directory" : "Aktuelles Verzeichnis neu laden",
     "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}“ wechseln",
     "Drag and drop files here to upload" : "Dateien zum Hochladen hierher ziehen und ablegen",
     "Your have used your space quota and cannot upload files anymore" : "Dein Speicherplatzkontigent ist aufgebraucht, du kannst keine weiteren Dateien hochladen.",
     "You don’t have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
+    "Favorite" : "Favorit",
     "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
     "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
     "Toggle selection for file \"{displayName}\"" : "Auswahl für die Datei \"{displayName}\" umschalten",
     "Toggle selection for folder \"{displayName}\"" : "Auswahl für den Ordner \"{displayName}\" umschalten",
+    "File is loading" : "Datei wird geladen",
+    "Folder is loading" : "Ordner wird geladen",
     "Rename file" : "Datei umbenennen",
     "Filename" : "Dateiname",
     "Folder name" : "Ordnername",
@@ -196,15 +88,18 @@ OC.L10N.register(
     "Another entry with the same name already exists." : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
     "Invalid filename." : "Ungültiger Dateiname.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" in \"{newName}\" umbenannt",
-    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert.",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wähle einen anderen Namen.",
-    "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden.",
+    "Pending" : "Ausstehend",
     "Clear filter" : "Filter zurücksetzen",
+    "Modified" : "Geändert",
     "Type" : "Typ",
     "Active filters" : "Aktive Filter",
     "Remove filter" : "Filter entfernen",
     "Total rows summary" : "Zusammenfassung aller Zeilen",
+    "Name" : "Name",
+    "Size" : "Größe",
     "Toggle selection for all files and folders" : "Auswahl für alle Dateien und Ordner umschalten",
+    "Actions" : "Aktionen",
+    "(selected)" : "(ausgewählt)",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
     "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
     "{count} selected" : "{count} ausgewählt",
@@ -215,10 +110,13 @@ OC.L10N.register(
     "Storage information" : "Speicherinformation",
     "Storage quota" : "Speicherkontingent",
     "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
+    "{used} of {quota} used" : "{used} von {quota} verwendet",
     "{relative}% used" : "{relative}% verwendet",
     "Could not refresh storage stats" : "Die Speicherstatistik konnte nicht aktualisiert werden",
     "Your storage is full, files can not be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
     "Create" : "Erstellen",
+    "New folder" : "Neuer Ordner",
+    "Create new folder" : "Neuen Ordner erstellen",
     "This name is already in use." : "Dieser Name wird bereits verwendet.",
     "Fill template fields" : "Vorlagenfelder ausfüllen",
     "Submitting fields…" : "Felder werden übermittelt…",
@@ -235,12 +133,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Anforderung für die Übertragung des Besitzes gesendet",
     "Cannot transfer ownership of a file or folder you do not own" : "Der Besitz an einer Datei oder einem Ordner, der dir nicht gehört, kann nicht übertragen werden",
     "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
-    "Choose file" : "Datei auswählen",
     "Choose {file}" : "{file} auswählen",
     "Loading current folder" : "Lade aktuellen Ordner",
+    "Retry" : "Wiederholen",
     "No files in here" : "Keine Dateien vorhanden",
     "Upload some content or sync with your devices!" : "Lade Inhalte hoch oder synchronisiere sie mit deinen Geräten!",
-    "Go to the previous folder" : "Zum vorherigen Ordner wechseln",
     "Go back" : "Zurückgehen",
     "Share" : "Teilen",
     "Shared by link" : "Über einen Link geteilt",
@@ -248,6 +145,8 @@ OC.L10N.register(
     "Switch to list view" : "Zur Listenansicht wechseln",
     "Switch to grid view" : "Zur Rasteransicht wechseln",
     "Upload was cancelled by user" : "Das Hochladen wurde vom Benutzer abgebrochen.",
+    "Not enough free space" : "Nicht genügend freier Speicherplatz",
+    "Operation is blocked by access control" : "Vorgang wird durch die Zugangskontrolle blockiert",
     "Error during upload: {message}" : "Fehler beim Hochladen: {message}",
     "Error during upload, status code {status}" : "Fehler beim Hochladen, Statuscode {status}",
     "Unknown error during upload" : "unbekannte Fehler während des Hochladens",
@@ -272,6 +171,12 @@ OC.L10N.register(
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Wenn du 2FA aktiviert hast, musst du ein neues App-Passwort erstellen und verwenden, indem du hier klickst.",
     "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
     "WebDAV URL copied to clipboard" : "WebDAV-URL in die Zwischenablage kopiert",
+    "Owner" : "Besitzer",
+    "Remove from favorites" : "Von Favoriten entfernen",
+    "Add to favorites" : "Zu den Favoriten hinzufügen",
+    "Tags" : "Schlagworte",
+    "You" : "Du",
+    "Shared multiple times with different people" : "Mehrmals mit verschiedenen Personen geteilt",
     "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei konnte nicht geändert werden",
     "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
     "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
@@ -280,38 +185,50 @@ OC.L10N.register(
     "Blank" : "Leer",
     "Unable to create new file from template" : "Neue Datei konnte nicht aus Vorlage erstellt werden",
     "Deletion cancelled" : "Löschen abgebrochen",
+    "Leave this share" : "Diese Freigabe verlassen",
+    "Leave these shares" : "Diese Freigaben verlassen",
+    "Disconnect storage" : "Speicher trennen",
+    "Disconnect storages" : "Speicher trennen",
     "Delete permanently" : "Endgültig löschen",
     "Delete and unshare" : "Löschen und nicht mehr teilen",
-    "Leave these shares" : "Diese Freigaben verlassen",
-    "Disconnect storages" : "Speicher trennen",
+    "Delete file" : "Datei löschen",
     "Delete files" : "Dateien löschen",
+    "Delete folder" : "Ordner löschen",
     "Delete folders" : "Ordner löschen",
+    "Delete" : "Löschen",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Sie sind dabei, {count} Element endgültig zu löschen","Du bist dabei, {count} Elemente endgültig zu löschen."],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Sie sind dabei, {count} Element zu löschen","Du bist dabei, {count} Elemente zu löschen."],
     "Confirm deletion" : "Löschen bestätigen",
     "Cancel" : "Abbrechen",
     "Edit file locally" : "Datei lokal bearbeiten",
-    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "Die Datei sollte nun lokal geöffnet werden. Wenn dies nicht der Fall ist, stelle sicher, dass der Desktop-Client auf deinem System installiert ist.",
-    "Retry local edit" : "Lokale Bearbeitung erneut versuchen",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Die Datei sollte sich jetzt auf Ihrem Gerät öffnen. Wenn dies nicht der Fall ist, überprüfe, ob Du die Desktop-App installiert hast.",
+    "Retry and close" : "Erneut versuchen und schließen",
     "Edit online" : "Online bearbeiten",
-    "Destination is not a folder" : "Ziel ist kein Ordner",
-    "This file/folder is already in that directory" : "Diese Datei oder Ordner ist bereits in diesem Verzeichnis vorhanden",
+    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
+    "Edit locally" : "Lokal bearbeiten",
+    "Moving \"{source}\" to \"{destination}\" …" : "Verschiebe \"{source}\" nach \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopiere \"{source}\" nach \"{destination}\" …",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Eine Datei oder ein Ordner kann nicht auf sich selbst oder in einen Unterordner von sich selbst verschoben werden.",
-    "(copy)" : "(kopieren)",
-    "(copy %n)" : "(%n kopieren)",
+    "(copy)" : "(Kopie)",
+    "(copy %n)" : "(Kopie %n)",
     "Move cancelled" : "Verschieben abgebrochen",
     "A file or folder with that name already exists in this folder" : "In diesem Ordner ist bereits eine Datei oder ein Ordner mit diesem Namen vorhanden",
     "The files are locked" : "Die Dateien sind gesperrt",
     "The file does not exist anymore" : "Die Datei existiert nicht mehr",
     "Choose destination" : "Ziel wählen",
     "Copy to {target}" : "Nach {target} kopieren",
+    "Copy" : "Kopieren",
     "Move to {target}" : "Nach {target} verschieben",
+    "Move" : "Verschieben",
     "Move or copy operation failed" : "Verschiebe- oder Kopieroperation ist fehlgeschlagen.",
+    "Move or copy" : "Verschieben oder kopieren",
     "Cancelled move or copy of \"{filename}\"." : "Verschieben oder Kopieren von \"{filename}\" abgebrochen.",
     "Cancelled move or copy operation" : "Verschieben oder kopieren abgebrochen",
     "Open folder {displayName}" : "Ordner {displayName} öffnen",
     "Open in Files" : "In App \"Dateien\" öffnen",
+    "Rename" : "Umbenennen",
     "Open details" : "Details öffnen",
+    "View in folder" : "In Ordner anzeigen",
     "Today" : "Heute",
     "Last 7 days" : "Die letzten 7 Tage",
     "Last 30 days" : "Die letzten 30 Tage",
@@ -346,6 +263,10 @@ OC.L10N.register(
     "Files moved successfully" : "Dateien verschoben",
     "Conflicts resolution skipped" : "Konfliktelösung übersprungen",
     "Upload cancelled" : "Hochladen abgebrochen",
+    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder den Administrator kontaktieren.",
+    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
+    "Unexpected error: {error}" : "Unerwarteter Fehler: {error}",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} Ordner","{folderCount} Ordner"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} Datei","{fileCount} Dateien"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 Datei und {folderCount} Ordner","1 Datei und {folderCount} Ordner"],
@@ -356,7 +277,7 @@ OC.L10N.register(
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" ist ein reservierter Name und für Dateinamen nicht zulässig.",
     "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ist kein zulässiger Dateityp.",
     "Filenames must not end with \"{extension}\"." : "Dateinamen dürfen nicht mit \"{extension}\" enden.",
-    "List of favorites files and folders." : "Liste der favorisierten Ordner und Dateien",
+    "List of favorite files and folders." : "Liste der favorisierten Ordner und Dateien.",
     "No favorites yet" : "Noch keine Favoriten vorhanden",
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
     "All files" : "Alle Dateien",
@@ -366,26 +287,121 @@ OC.L10N.register(
     "List of your files and folders that are not shared." : "Liste deiner Dateien und Ordner, die nicht geteilt wurden.",
     "No personal files found" : "Keine persönlichen Dateien gefunden",
     "Files that are not shared will show up here." : "Dateien, die nicht geteilt wurden, werden hier angezeigt.",
+    "Recent" : "Neueste",
     "List of recently modified files and folders." : "Liste der zuletzt geänderten Dateien und Ordner",
     "No recently modified files" : "Keine kürzlich geänderten Dateien",
     "Files and folders you recently modified will show up here." : "Die von dir kürzlich geänderten Dateien und Ordner werden hier angezeigt.",
+    "You do not have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
     "Select all" : "Alle auswählen",
     "Upload too large" : "Der Upload ist zu groß",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
-    "Text file" : "Textdatei",
-    "New text file.txt" : "Neue Textdatei file.txt",
+    "File could not be found" : "Datei konnte nicht gefunden werden",
+    "Download" : "Herunterladen",
+    "Show list view" : "Listenansicht anzeigen",
+    "Show grid view" : "Rasteransicht anzeigen",
+    "Close" : "Schließen",
+    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
+    "This will stop your current uploads." : "Hiermit werden die aktuellen Uploads angehalten.",
+    "Upload cancelled." : "Hochladen abgebrochen.",
+    "Processing files …" : "Dateien werden verarbeitet …",
+    "…" : "…",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, du möchtest{size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
+    "Target folder \"{dir}\" does not exist any more" : "Ziel-Verzeichnis \"{dir}\" existiert nicht mehr",
+    "An unknown error has occurred" : "Es ist ein unbekannter Fehler aufgetreten",
+    "File could not be uploaded" : "Datei konnte nicht hochgeladen werden.",
+    "Uploading …" : "Lade hoch …",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Lade hoch … ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Hochladen von Daten dieser Art wird nicht unterstützt.",
+    "Error when assembling chunks, status code {status}" : "Fehler beim Zusammenführen der Teile (Chunks), Fehlermeldung {status}",
+    "Choose target folder" : "Zielordner wählen",
+    "Set reminder" : "Erinnerung erstellen",
+    "Open" : "Öffnen",
+    "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
+    "Details" : "Details",
+    "Please select tag(s) to add to the selection" : "Bitte wähle das/die Schlagwort(e) aus, das/die du zur Auswahl hinzufügen möchtest",
+    "Apply tag(s) to selection" : "Schlagwort(e) auf die Auswahl anwenden",
+    "Select directory \"{dirName}\"" : "Verzeichnis \"{dirName}\" auswählen",
+    "Select file \"{fileName}\"" : "Datei \"{fileName}\" auswählen",
+    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
+    "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
+    "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
+    "copy" : "Kopie",
+    "Could not copy \"{file}\", target exists" : "\"{file}\" konnte nicht kopiert werden, Ziel existiert bereits",
+    "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
+    "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
+    "{newName} already exists" : "{newName} existiert bereits",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei \"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte einen anderen Namen verwenden.",
+    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
+    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert.",
+    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner \"{dir}\" konnte nicht erstellt werden, da dieser bereits existiert",
+    "Could not fetch file details \"{file}\"" : "Details zu \"{file}\" konnten nicht ermittelt werden",
+    "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "Gib mehr als zwei Zeichen ein, um in anderen Ordnern zu suchen.",
+    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
+    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
+    "{dirs} and {files}" : "{dirs} und {files}",
+    "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
+    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
+    "New" : "Neu",
+    "New file/folder menu" : "Menü für neue Datei/Ordner",
+    "Select file range" : "Dateibereich auswählen",
+    "{used}%" : "{used}%",
+    "{used} used" : "{used} verwendet",
+    "\"{name}\" is an invalid file name." : "„{name}“ ist kein gültiger Dateiname.",
+    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
+    "\"/\" is not allowed inside a file name." : "\"/\" ist innerhalb eines Dateinamens nicht erlaubt.",
+    "\"{name}\" is not an allowed filetype" : "„{name}“ ist kein erlaubter Dateityp",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppenordner \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externer Speicher \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppenordner \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externer Speicher \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Dein Speicher ist beinahe voll ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
     "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Benutzer, die Zugriff auf diese Datei/Ordner haben)",
+    "Path" : "Pfad",
+    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
+    "Favorited" : "Favorisiert",
     "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
+    "Upload file" : "Datei hochladen",
+    "Not favorited" : "Nicht favorisiert",
+    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
     "\"remote user\"" : "„Externer Benutzer“",
     "{newName} already exists." : "{newName} existiert bereits.",
+    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" ist in einem Dateinamen unzulässig.",
+    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" ist ein unzulässiger Datei- oder Ordnername.",
+    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" ist kein zulässiger Dateityp.",
+    "Filenames must not end with \"{segment}\"." : "Dateinamen dürfen nicht mit \"{segment}\" enden.",
     "Name cannot be empty" : "Der Name darf nicht leer sein",
     "Another entry with the same name already exists" : "Ein anderer Eintrag mit diesem Namen existiert bereits.",
+    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" konnte nicht umbenannt werden, da es nicht mehr existiert.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{newName}“ wird bereits im Ordner \"{dir}“ verwendet. Bitte wähle einen anderen Namen.",
+    "Could not rename \"{oldName}\"" : "\"{oldName}\" konnte nicht umbenannt werden.",
     "Storage informations" : "Speicherinformationen",
+    "Choose file" : "Datei auswählen",
+    "Go to the previous folder" : "Zum vorherigen Ordner wechseln",
     "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
     "You might not have have permissions to view it, ask the sender to share it" : "Möglicherweise hast du nicht die Berechtigung zur Anzeige. Bitte den Absender, die Datei freizugeben.",
     "The files is locked" : "Die Datei ist gesperrt",
     "Create new templates folder" : "Neuen Vorlagenordner erstellen",
-    "Toggle %1$s sublist" : "Unterliste %1$s umschalten"
+    "List of favorites files and folders." : "Liste der favorisierten Ordner und Dateien",
+    "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
+    "Text file" : "Textdatei",
+    "New text file.txt" : "Neue Textdatei file.txt",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlink wurde kopiert (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Direktlink kopieren (funktioniert nur für Personen, die Zugriff auf diese Datei/Ordner haben)",
+    "Favored" : "Favorisiert",
+    "Favor" : "Favorisieren",
+    "Not favored" : "Nicht favorisiert"
 },
 "nplurals=2; plural=(n != 1);");
