@@ -1,120 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "Datoteke ni mogoče najti",
-    "Move or copy" : "Premakni ali kopiraj",
-    "Download" : "Prejmi",
-    "Delete" : "Izbriši",
-    "Tags" : "Oznake",
-    "Show list view" : "Pokaži seznamski pogled",
-    "Show grid view" : "Pokaži mrežni pogled",
-    "Home" : "Začetni pogled",
-    "Close" : "Zapri",
-    "Could not create folder \"{dir}\"" : "Mape »{dir}« ni mogoče ustvariti.",
-    "This will stop your current uploads." : "S tem bodo zaustavljena vsa pošiljanja v oblak.",
-    "Upload cancelled." : "Pošiljanje je preklicano.",
-    "Processing files …" : "Poteka obdelava datotek ...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Datoteke {filename} ni mogoče poslati, saj je to mapa, ali pa je velikost datoteke 0 bajtov.",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je le {size2}.",
-    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa »{dir}« ne obstaja več.",
-    "Not enough free space" : "Ni dovolj prostora",
-    "An unknown error has occurred" : "Prišlo je do neznane napake!",
-    "File could not be uploaded" : "Datoteke ni mogoče poslati",
-    "Uploading …" : "Poteka pošiljanje ...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Pošiljanje … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Pošiljate te vrste predmeta ni podprto.",
-    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
-    "Operation is blocked by access control" : "Opravilo je zaustavljeno prek nadzora dostopa",
-    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov datoteke, koda stanja je {status}",
-    "Actions" : "Dejanja",
-    "Rename" : "Preimenuj",
-    "Move" : "Premakni",
-    "Copy" : "Kopiraj",
-    "Choose target folder" : "Izbor ciljne mape",
-    "Set reminder" : "Nastavi opomnik",
-    "Edit locally" : "Uredi krajevno",
-    "Open" : "Odpri",
-    "Delete file" : "Izbriši datoteko",
-    "Delete folder" : "Izbriši mapo",
-    "Disconnect storage" : "Odklopi shrambo",
-    "Leave this share" : "Prekini to souporabo",
-    "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podatkov za datoteko »{file}«.",
-    "Files" : "Datoteke",
-    "Details" : "Podrobnosti",
-    "Please select tag(s) to add to the selection" : "Izbrati je treba oznake za dodajanje k izbiri",
-    "Apply tag(s) to selection" : "Poteka uveljavljanje oznak za izbiro",
-    "Select directory \"{dirName}\"" : "Izberi mapo »{dirName}«",
-    "Select file \"{fileName}\"" : "Izberi datoteko »{fileName}«.",
-    "Pending" : "Na čakanju ...",
-    "Unable to determine date" : "Ni mogoče določiti datuma",
-    "This operation is forbidden" : "To dejanje ni dovoljeno!",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
-    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
-    "Could not move \"{file}\", target exists" : "Datoteke »{file}« ni mogoče premakniti, ker na ciljnem mestu z istim imenom že obstaja.",
-    "Could not move \"{file}\"" : "Datoteke »{file}« ni mogoče premakniti",
-    "copy" : "kopija",
-    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja.",
-    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
-    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
-    "Failed to redirect to client" : "Preusmerjanje odjemalca je spodletelo",
-    "{newName} already exists" : "Ime {newName} že obstaja",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Datoteke »{fileName}« ni mogoče preimenovati, ker ne obstaja več",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
-    "Could not rename \"{fileName}\"" : "Datoteke »{fileName}« ni mogoče preimenovati",
-    "Could not create file \"{file}\"" : "Datoteke »{file}« ni mogoče ustvariti.",
-    "Could not create file \"{file}\" because it already exists" : "Datoteke »{file}« ni mogoče ustvariti, ker datoteka z istim imenom že obstaja.",
-    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape »{dir}«, ker ta že obstaja",
-    "Could not fetch file details \"{file}\"" : "Ni mogoče pridobiti podrobnosti datoteke »{file}«.",
-    "Error deleting file \"{fileName}\"." : "Prišli je do napake med brisanjem datoteke »{fileName}«.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
-    "Enter more than two characters to search in other folders" : "Vpišite več kot dva znaka za iskanje po drugih mapah",
-    "Name" : "Ime",
-    "Size" : "Velikost",
-    "Modified" : "Spremenjeno",
-    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
-    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
-    "{dirs} and {files}" : "{dirs} in {files}",
-    "_including %n hidden_::_including %n hidden_" : ["vključujoč %n skrito","vključujoč %n skriti","vključujoč %n skrite","vključujoč %n skritih"],
-    "You do not have permission to upload or create files here" : "Ni ustreznih dovoljenja za pošiljanje ali ustvarjanje novih datotek",
-    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Poteka posodabljanje %n datotek"],
-    "New" : "Novo",
-    "New file/folder menu" : "Nov meni datoteke/mape",
-    "Select file range" : "Izbor obsega datotek",
-    "{used}%" : "{used} %",
-    "{used} of {quota} used" : "V uporabi je {used} od {quota}",
-    "{used} used" : "V uporabi je {used}",
-    "\"{name}\" is an invalid file name." : "Ime »{name}« ni veljavno ime datoteke.",
-    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
-    "\"/\" is not allowed inside a file name." : "znak » / « v imenu datoteke ni dovoljen.",
-    "\"{name}\" is not an allowed filetype" : "Ime »{name}« ni dovoljena vrsta datoteke.",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Skupinska mapa »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Zunanja shramba »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Shramba uporabnika {owner} je do konca zasedena ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Skupinska mapa »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Zunanja shramba »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Vaša shramba je skoraj do konca zasedena ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["se skladajo s filtrom »{filter}«","se skladajo s filtroma »{filter}«","se skladajo s filtri »{filter}«","se skladajo s filtri »{filter}«"],
-    "View in folder" : "Pokaži v mapi",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
-    "Path" : "Pot",
-    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
-    "Favorited" : "Označeno kot priljubljeno",
-    "Favorite" : "Priljubljene",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
-    "New folder" : "Nova mapa",
-    "Create new folder" : "Ustvari novo mapo",
-    "Upload file" : "Pošlji datoteko",
-    "Recent" : "Nedavne",
-    "Not favorited" : "Ni priljubljeno",
-    "Remove from favorites" : "Odstrani iz priljubljenih",
-    "Add to favorites" : "Dodaj med priljubljene",
-    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
     "Added to favorites" : "Dodano med priljubljene",
     "Removed from favorites" : "Odstranjeno iz priljubljenih",
     "You added {file} to your favorites" : "Med priljubljene dodate datoteko {file}",
@@ -154,11 +40,13 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Premaknete datoteko {oldfile} v {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} premakne datoteko {oldfile} v {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila, ali dodana ali umaknjena iz <strong>priljubljenih</strong>",
+    "Files" : "Datoteke",
     "A file or folder has been <strong>changed</strong>" : "<strong>Spremenjena</strong> je bila datoteka ali mapa",
     "A favorite file or folder has been <strong>changed</strong>" : "<strong>Spremenjena</strong> je bila priljubljena datoteka ali mapa",
+    "Failed to authorize" : "Overitev je spodletela",
+    "Invalid folder path" : "Neveljavna pot mape",
+    "Folder not found" : "Mape ni mogoče najti",
     "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
-    "Files compatibility" : "Skladnost datotek",
-    "Enforce Windows compatibility" : "Vsili skladnost s sistemom Windows",
     "Accept" : "Sprejmi",
     "Reject" : "Zavrni",
     "Incoming ownership transfer from {user}" : "Vpisana je zahteva za prenos lastništva uporabnika {user}",
@@ -171,37 +59,57 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "Prenos lastništva poti {path} na uporabnika {user} je končan.",
     "The ownership transfer of {path} from {user} has completed." : "Prenos lastništva poti {path} z uporabnika {user} je končan.",
     "in %s" : "v %s",
+    "Files compatibility" : "Skladnost datotek",
+    "Enforce Windows compatibility" : "Vsili skladnost s sistemom Windows",
     "File Management" : "Upravljanje datotek",
     "Current directory path" : "Trenutna pot mape",
+    "Home" : "Začetni pogled",
+    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
     "Reload current directory" : "Ponovno naloži trenutno mapo",
     "Go to the \"{dir}\" directory" : "Pojdi v mapo »{dir}«",
     "Drag and drop files here to upload" : "Za pošiljanje potegnite in spustite datoteke na to mesto",
     "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje in ustvarjanje datotek na tem mestu.",
+    "Favorite" : "Priljubljene",
     "\"{displayName}\" action executed successfully" : "Dejanje »{displayName}« je uspešno izvedeno",
     "\"{displayName}\" action failed" : "Dejanje »{displayName}« je spodletelo",
+    "File is loading" : "Poteka nalaganje datoteke",
+    "Folder is loading" : "mape",
     "Rename file" : "Preimenuj datoteke",
     "Filename" : "Ime datoteke",
     "Folder name" : "Ime mape",
     "This node is unavailable" : "To vozlišče ni na voljo.",
+    "Invalid filename." : "Neveljavno ime datoteke",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Preimenuj »{oldName}« to »{newName}«",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Datoteke »{oldName}« ni mogoče preimenovati, ker ne obstaja več.",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime »{newtName}« je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
-    "Could not rename \"{oldName}\"" : "Datoteke »{oldName}« ni mogoče preimenovati",
+    "Pending" : "Na čakanju ...",
     "Clear filter" : "Počisti filter",
+    "Modified" : "Spremenjeno",
     "Type" : "Vrsta",
     "Active filters" : "Dejavni filtri",
+    "Remove filter" : "Odstrani filter",
     "Total rows summary" : "Skupni povzetek vrstic",
+    "Name" : "Ime",
+    "Size" : "Velikost",
+    "Actions" : "Dejanja",
+    "(selected)" : "(izbrano)",
     "\"{displayName}\" failed on some elements " : "Dejanje »{displayName}« je pri nekaterih predmetih spodletelo",
     "\"{displayName}\" batch action executed successfully" : "Paketno dejanje »{displayName}« je uspešno izvedeno",
     "{count} selected" : "{count} izbranih",
     "List of files and folders." : "Seznam datotek in map",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Seznam datotek ni v celoti izpisan zaradi zagotavljanja hitrosti in odzivnosti sistema. Predmeti se bodo dopolnjevali med brskanjem.",
     "File not found" : "Datoteke ni mogoče najti",
+    "Storage information" : "Podrobnosti shrambe",
+    "Storage quota" : "Omejitev shrambe",
     "{usedQuotaByte} used" : "Zasedeno {usedQuotaByte}",
+    "{used} of {quota} used" : "V uporabi je {used} od {quota}",
     "{relative}% used" : "Zasedeno {relative} %",
     "Could not refresh storage stats" : "Ni mogoče osvežiti podatkov shrambe",
     "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
     "Create" : "Ustvari",
+    "New folder" : "Nova mapa",
+    "Create new folder" : "Ustvari novo mapo",
+    "This name is already in use." : "Vpisano uporabniško ime je že v uporabi",
+    "Fill template fields" : "Zapolni polja predloge",
+    "Submitting fields…" : "Poteka objavljanje vsebine polj ...",
     "Submit" : "Pošlji",
     "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
     "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
@@ -215,18 +123,22 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Zahteva za prenos lastništva je poslana",
     "Cannot transfer ownership of a file or folder you do not own" : "Ni mogoče prenesti lastništva datotek in map, katerih niste lastnik",
     "Select file or folder to link to" : "Izbor datoteke ali mape za povezavo",
-    "Choose file" : "Izbor datotek",
     "Choose {file}" : "Izberite datoteko {file}",
     "Loading current folder" : "Poteka nalaganje trenutne mape",
+    "Retry" : "Poskusi znova",
     "No files in here" : "V mapi ni datotek",
     "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
-    "Go to the previous folder" : "Skoči na predhodno mapo",
     "Go back" : "Skoči nazaj",
     "Share" : "·Souporaba·",
     "Shared by link" : "V souporabi sk povezavo",
     "Shared" : "V souporabi",
     "Switch to list view" : "Preklopi na seznamski pogled",
     "Switch to grid view" : "Preklopi na mrežni pogled",
+    "Upload was cancelled by user" : "Uporabnik je pošiljanje preklical",
+    "Not enough free space" : "Ni dovolj prostora",
+    "Operation is blocked by access control" : "Opravilo je zaustavljeno prek nadzora dostopa",
+    "Unknown error during upload" : "Med pošiljanjem je prišlo do neznane napake",
+    "Filter filenames…" : "Filtriraj imena datotek ...",
     "Views" : "Pogledi",
     "Files settings" : "Nastavitve datotek",
     "File cannot be accessed" : "Do datoteke dostop ni mogoč",
@@ -237,6 +149,7 @@ OC.L10N.register(
     "Show hidden files" : "Pokaži skrite datoteke",
     "Crop image previews" : "Obreži slike predogleda",
     "Enable the grid view" : "Omogoči mrežni pogled",
+    "Enable folder tree" : "Omogoči drevesno strukturo map",
     "Additional settings" : "Dodatne nastavitve",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "Naslov URL WebDAV",
@@ -245,6 +158,10 @@ OC.L10N.register(
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Če je omogočen sistem dvostopenjskega overjanja 2FA, je treba ustvariti in uporabiti novo geslo programa s klikom na to mesto.",
     "Clipboard is not available" : "Odložišče ni na voljo",
     "WebDAV URL copied to clipboard" : "Naslov URL WebDAV je kopiran v odložišče",
+    "Remove from favorites" : "Odstrani iz priljubljenih",
+    "Add to favorites" : "Dodaj med priljubljene",
+    "Tags" : "Oznake",
+    "You" : "Jaz",
     "Unable to change the favourite state of the file" : "Ni mogoče spremeniti stanja priljubljenosti datoteke",
     "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
     "Pick a template for {name}" : "Izbor predloge za {name}",
@@ -253,77 +170,198 @@ OC.L10N.register(
     "Blank" : "Prazno",
     "Unable to create new file from template" : "Nove datoteke iz predloge ni mogoče ustvariti",
     "Deletion cancelled" : "Brisanje je bilo preklicano",
+    "Leave this share" : "Prekini to souporabo",
+    "Leave these shares" : "Prekini to souporabo",
+    "Disconnect storage" : "Odklopi shrambo",
+    "Disconnect storages" : "Odklopi shrambo",
     "Delete permanently" : "Izbriši trajno",
     "Delete and unshare" : "Izbriši in prekini souporabo",
-    "Leave these shares" : "Prekini to souporabo",
-    "Disconnect storages" : "Odklopi shrambo",
+    "Delete file" : "Izbriši datoteko",
     "Delete files" : "Izbriši datoteki",
+    "Delete folder" : "Izbriši mapo",
     "Delete folders" : "Izbriši mape",
+    "Delete" : "Izbriši",
     "Confirm deletion" : "Potrdi brisanje",
     "Cancel" : "Prekliči",
-    "Destination is not a folder" : "Ciljno mesto ni mapa",
-    "This file/folder is already in that directory" : "Ta datoteka oziroma mapa je že v določeni mapi",
+    "Edit file locally" : "Uredi datoteko krajevno",
+    "Edit online" : "Uredi na spletu",
+    "Failed to redirect to client" : "Preusmerjanje odjemalca je spodletelo",
+    "Edit locally" : "Uredi krajevno",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Mape ali datoteke ni mogoče premakniti samo vase oziroma v podmapo same sebe",
     "(copy)" : "(kopija)",
     "(copy %n)" : "(kopija %n)",
     "Move cancelled" : "Premikanje je bilo preklicano",
     "A file or folder with that name already exists in this folder" : "Datoteka oziroma mapa s tem imenom v tej mapi že obstaja",
+    "The files are locked" : "Datoteke so zaklenjene",
     "The file does not exist anymore" : "Datoteka ne obstaja več",
     "Choose destination" : "Izbor ciljnega mesta",
     "Copy to {target}" : "Kopiraj na {target}",
+    "Copy" : "Kopiraj",
     "Move to {target}" : "Premakni na {target}",
+    "Move" : "Premakni",
+    "Move or copy operation failed" : "Opravilo kopiranja oziroma premikanja je spodletelo",
+    "Move or copy" : "Premakni ali kopiraj",
     "Cancelled move or copy operation" : "Opravilo kopiranje in premikanja je preklicano",
     "Open folder {displayName}" : "Odpri mapo {displayName}",
     "Open in Files" : "Open in Files",
+    "Rename" : "Preimenuj",
     "Open details" : "Odpri podrobnosti",
+    "View in folder" : "Pokaži v mapi",
     "Today" : "Danes",
     "Last 7 days" : "Zadnjih 7 dni",
     "Last 30 days" : "Zadnjih 30 dni",
+    "This year ({year})" : "Letos ({year})",
+    "Last year ({year})" : "Lansko leto ({year})",
     "Documents" : "Dokumenti",
+    "Spreadsheets" : "Preglednice",
+    "Presentations" : "Predstavitve",
+    "PDFs" : "Dokumenti PDF",
     "Folders" : "Mape",
     "Audio" : "Zvočni posnetek",
+    "Photos and images" : "Slike in fotografije",
     "Videos" : "Video posnetki",
+    "New folder creation cancelled" : "Ustvarjanje nove mape je bilo preklicano",
     "Created new folder \"{name}\"" : "Ustvarjena je nova mapa »{name}«.",
     "Unable to initialize the templates directory" : "Ni mogoče začeti mape predlog",
+    "Create templates folder" : "Ustvari mapo predlog",
     "Templates" : "Predloge",
     "New template folder" : "Nova mapa predlog",
+    "In folder" : "V mapi",
+    "Search in folder: {folder}" : "Išči v mapi: {folder}",
+    "No files to upload" : "Ni datotek za pošiljanje",
+    "Some files could not be uploaded" : "Nekaterih datotek ni bilo mogoče poslati",
     "Files uploaded successfully" : "Datoteke so uspešno poslane v oblak",
+    "No files to process" : "Ni datotek za obdelavo",
+    "Some files could not be copied" : "Nekaterih datotek ni bilo mogoče kopirati",
     "Some files could not be moved" : "Nekaterih datotek ni mogoče premakniti",
     "Files copied successfully" : "Datoteke so uspešno kopirane",
     "Files moved successfully" : "Datoteke so uspešno premaknjene",
+    "Conflicts resolution skipped" : "Razreševanje sporov je preklicano",
     "Upload cancelled" : "Pošiljanje je bilo preklicano",
+    "This operation is forbidden" : "To dejanje ni dovoljeno!",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
+    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapa","{folderCount} mapi","{folderCount} mape","{folderCount} map"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} datoteka","{fileCount} datoteki","{fileCount} datoteke","{fileCount} datotek"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 datoteka in {folderCount} mapa","1 datoteka in {folderCount} mapi","1 datoteka in {folderCount} mape","1 datoteka in {folderCount} map"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} datoteka in 1 mapa","{fileCount} datoteki in 1 mapa","{fileCount} datoteke in 1 mapa","{fileCount} datotek in 1 mapa"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} datotek in {folderCount} map",
-    "List of favorites files and folders." : "Seznam priljubljenih datotek in map.",
+    "Filename must not be empty." : "Ime datoteke ne sme biti prazno.",
     "No favorites yet" : "Ni še dodanih priljubljenih predmetov",
     "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
     "All files" : "Vse datoteke",
     "List of your files and folders." : "Seznam datotek in map.",
+    "All folders" : "Vse mape",
     "Personal Files" : "Osebne datoteke",
     "No personal files found" : "Ni najdenih zasebnih datotek",
+    "Recent" : "Nedavne",
     "List of recently modified files and folders." : "Seznam nedavno spremenjenih datotek in map.",
     "No recently modified files" : "Ni nedavno spremenjenih datotek",
     "Files and folders you recently modified will show up here." : "Nedavno spremenjene datoteke ali mape, bodo zbrane na tem mestu.",
+    "You do not have permission to upload or create files here" : "Ni ustreznih dovoljenja za pošiljanje ali ustvarjanje novih datotek",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
     "Select all" : "izberi vse",
     "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
-    "Text file" : "Besedilna datoteka",
-    "New text file.txt" : "nova_datoteka.txt",
+    "File could not be found" : "Datoteke ni mogoče najti",
+    "Download" : "Prejmi",
+    "Show list view" : "Pokaži seznamski pogled",
+    "Show grid view" : "Pokaži mrežni pogled",
+    "Close" : "Zapri",
+    "Could not create folder \"{dir}\"" : "Mape »{dir}« ni mogoče ustvariti.",
+    "This will stop your current uploads." : "S tem bodo zaustavljena vsa pošiljanja v oblak.",
+    "Upload cancelled." : "Pošiljanje je preklicano.",
+    "Processing files …" : "Poteka obdelava datotek ...",
+    "…" : "...",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Datoteke {filename} ni mogoče poslati, saj je to mapa, ali pa je velikost datoteke 0 bajtov.",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ni dovolj prostora. Velikost poslane datoteke je {size1}, na voljo pa je le {size2}.",
+    "Target folder \"{dir}\" does not exist any more" : "Ciljna mapa »{dir}« ne obstaja več.",
+    "An unknown error has occurred" : "Prišlo je do neznane napake!",
+    "File could not be uploaded" : "Datoteke ni mogoče poslati",
+    "Uploading …" : "Poteka pošiljanje ...",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Pošiljanje … ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} od {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "Pošiljate te vrste predmeta ni podprto.",
+    "Error when assembling chunks, status code {status}" : "Napaka pri sestavljanju kosov datoteke, koda stanja je {status}",
+    "Choose target folder" : "Izbor ciljne mape",
+    "Set reminder" : "Nastavi opomnik",
+    "Open" : "Odpri",
+    "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podatkov za datoteko »{file}«.",
+    "Details" : "Podrobnosti",
+    "Please select tag(s) to add to the selection" : "Izbrati je treba oznake za dodajanje k izbiri",
+    "Apply tag(s) to selection" : "Poteka uveljavljanje oznak za izbiro",
+    "Select directory \"{dirName}\"" : "Izberi mapo »{dirName}«",
+    "Select file \"{fileName}\"" : "Izberi datoteko »{fileName}«.",
+    "Unable to determine date" : "Ni mogoče določiti datuma",
+    "Could not move \"{file}\", target exists" : "Datoteke »{file}« ni mogoče premakniti, ker na ciljnem mestu z istim imenom že obstaja.",
+    "Could not move \"{file}\"" : "Datoteke »{file}« ni mogoče premakniti",
+    "copy" : "kopija",
+    "Could not copy \"{file}\", target exists" : "Datoteke »{file}« ni mogoče kopirati, ker ta že obstaja.",
+    "Could not copy \"{file}\"" : "Datoteke »{file}« ni mogoče kopirati.",
+    "Copied {origin} inside {destination}" : "Kopirano {origin} v {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopirano {origin} in {nbfiles} ostale datoteke v {destination}",
+    "{newName} already exists" : "Ime {newName} že obstaja",
+    "Could not rename \"{fileName}\", it does not exist any more" : "Datoteke »{fileName}« ni mogoče preimenovati, ker ne obstaja več",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime \"{targetName}\" je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
+    "Could not rename \"{fileName}\"" : "Datoteke »{fileName}« ni mogoče preimenovati",
+    "Could not create file \"{file}\"" : "Datoteke »{file}« ni mogoče ustvariti.",
+    "Could not create file \"{file}\" because it already exists" : "Datoteke »{file}« ni mogoče ustvariti, ker datoteka z istim imenom že obstaja.",
+    "Could not create folder \"{dir}\" because it already exists" : "Ni mogoče ustvariti mape »{dir}«, ker ta že obstaja",
+    "Could not fetch file details \"{file}\"" : "Ni mogoče pridobiti podrobnosti datoteke »{file}«.",
+    "Error deleting file \"{fileName}\"." : "Prišli je do napake med brisanjem datoteke »{fileName}«.",
+    "No search results in other folders for {tag}{filter}{endtag}" : "Za iskalni niz {tag}{filter}{endtag} ni zadetkov v nobeni mapi",
+    "Enter more than two characters to search in other folders" : "Vpišite več kot dva znaka za iskanje po drugih mapah",
+    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
+    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
+    "{dirs} and {files}" : "{dirs} in {files}",
+    "_including %n hidden_::_including %n hidden_" : ["vključujoč %n skrito","vključujoč %n skriti","vključujoč %n skrite","vključujoč %n skritih"],
+    "_Uploading %n file_::_Uploading %n files_" : ["Posodabljanje %n datoteke","Posodabljanje %n datotek","Posodabljanje %n datotek","Poteka posodabljanje %n datotek"],
+    "New" : "Novo",
+    "New file/folder menu" : "Nov meni datoteke/mape",
+    "Select file range" : "Izbor obsega datotek",
+    "{used}%" : "{used} %",
+    "{used} used" : "V uporabi je {used}",
+    "\"{name}\" is an invalid file name." : "Ime »{name}« ni veljavno ime datoteke.",
+    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
+    "\"/\" is not allowed inside a file name." : "znak » / « v imenu datoteke ni dovoljen.",
+    "\"{name}\" is not an allowed filetype" : "Ime »{name}« ni dovoljena vrsta datoteke.",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Shramba uporabnika {owner} je polna, zato datotek ni več mogoče posodabljati in usklajevati!",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Skupinska mapa »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Zunanja shramba »{mountPoint}« je do konca zasedena, zato datotek ni mogoče več posodobiti in usklajevati!",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Shramba uporabnika {owner} je do konca zasedena ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Skupinska mapa »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Zunanja shramba »{mountPoint}« je skoraj do konca zasedena ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Vaša shramba je skoraj do konca zasedena ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["se skladajo s filtrom »{filter}«","se skladajo s filtroma »{filter}«","se skladajo s filtri »{filter}«","se skladajo s filtri »{filter}«"],
     "Direct link was copied (only works for users who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
+    "Path" : "Pot",
+    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
+    "Favorited" : "Označeno kot priljubljeno",
     "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
+    "Upload file" : "Pošlji datoteko",
+    "Not favorited" : "Ni priljubljeno",
+    "An error occurred while trying to update the tags" : "Prišlo je do napake med posodabljanjem oznak",
     "\"remote user\"" : "»Oddaljen uporabnik«",
     "{newName} already exists." : "Ime {newName} že obstaja.",
     "Name cannot be empty" : "Polje imena ne sme biti prazno",
     "Another entry with the same name already exists" : "Vpis s tem imenom že obstaja.",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Datoteke »{oldName}« ni mogoče preimenovati, ker ne obstaja več.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime »{newName}« je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
+    "Could not rename \"{oldName}\"" : "Datoteke »{oldName}« ni mogoče preimenovati",
     "Storage informations" : "Podrobnosti shrambe",
+    "Choose file" : "Izbor datotek",
+    "Go to the previous folder" : "Skoči na predhodno mapo",
     "Open the files app settings" : "Odpri nastavitve programa Datoteke",
     "You might not have have permissions to view it, ask the sender to share it" : "Morda ni ustreznih dovoljenj za ogled. Prosite pošiljatelja za prilagoditev.",
     "The files is locked" : "Datoteka je zaklenjena",
     "Create new templates folder" : "Ustvari novo začasno mapo",
-    "Toggle %1$s sublist" : "Preklopi podseznam %1$s"
+    "List of favorites files and folders." : "Seznam priljubljenih datotek in map.",
+    "Toggle %1$s sublist" : "Preklopi podseznam %1$s",
+    "Text file" : "Besedilna datoteka",
+    "New text file.txt" : "nova_datoteka.txt",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
