@@ -25,6 +25,7 @@ OC.L10N.register(
     "Nextcloud Assistant" : "Nextcloud アシスタント",
     "Translate" : "翻訳",
     "Show assistant results" : "アシスタントの結果を表示する",
+    "Assistant results" : "アシスタントの結果",
     "Insert result" : "結果を挿入する",
     "Show result" : "結果を表示する",
     "Delete task" : "タスクを削除",
@@ -54,6 +55,7 @@ OC.L10N.register(
     "Show link preview" : "リンクのプレビューを表示",
     "Remove link" : "リンクを削除",
     "guest" : "ゲスト",
+    "Full width editor" : "フルワイドエディタ",
     "Active people" : "ファイルを開いているユーザー",
     "Save document" : "ファイルを保存する",
     "Last saved" : "最終保存",
@@ -138,6 +140,7 @@ OC.L10N.register(
     "Select language" : "言語を選択する",
     "Text to translate from" : "翻訳元テキスト",
     "to" : "訳文の言語",
+    "Translate to" : "翻訳先",
     "Translated text result" : "テキスト翻訳の結果",
     "Replace" : "入れ替え",
     "Insert" : "挿入する",
@@ -173,6 +176,7 @@ OC.L10N.register(
     "Add column after" : "列を右に追加する",
     "Delete this column" : "この列を削除する",
     "Delete this table" : "この表を削除する",
+    "Add row below" : "行を下に追加する",
     "Show folder description" : "フォルダーの概要を表示する",
     "Hide outline" : "目次を隠す",
     "Show outline" : "目次を表示する",
@@ -181,21 +185,24 @@ OC.L10N.register(
     "Heading 3" : "見出し3",
     "Heading 4" : "見出し4",
     "Heading 5" : "見出し5",
+    "Lists" : "リスト",
     "To-Do list" : "To-Do リスト",
-    "Insert link" : "リンクを挿入する",
-    "Callouts" : "コールアウト",
-    "Info" : "情報",
-    "Success" : "完了",
-    "Warning" : "警告",
-    "Danger" : "危険",
+    "Increase indentation" : "インデントを増やす",
+    "Decrease indentation" : "インデントを減らす",
+    "Blocks" : "ブロック",
+    "Info callout" : "情報コールアウト",
+    "Success callout" : "成功コールアウト",
+    "Warning callout" : "警告コールアウト",
+    "Danger callout" : "危険コールアウト",
     "Table" : "表",
     "Details" : "詳細",
+    "Insert link" : "リンクを挿入する",
     "Insert attachment" : "添付ファイルを挿入する",
     "Command" : "コマンド",
     "Control" : "コントロール",
     "Option" : "Option",
     "Formatting" : "フォーマット",
-    "Add notes, lists or links …" : "ノート、リスト、リンクを追加...",
+    "Start writing, or try '/' to add, '@' to mention…" : "書き始めるか、「/」で追加、「@」でメンション...。",
     "Add folder description" : "フォルダーの説明を追加",
     "\"{name}\" already exist!" : "\"{name}\" は既に存在します",
     "Created \"{name}\"" : "\"{name}\" を作成しました",
@@ -205,6 +212,12 @@ OC.L10N.register(
     "Link to this section" : "このセクションへのリンク",
     "Show author colors" : "記入者の色をつける",
     "Author colors are only shown until everyone has closed the document." : "記入者の色は、全員がドキュメントを閉じるまで表示されます。",
+    "Callouts" : "コールアウト",
+    "Info" : "情報",
+    "Success" : "完了",
+    "Warning" : "警告",
+    "Danger" : "危険",
+    "Add notes, lists or links …" : "ノート、リスト、リンクを追加...",
     "Add description" : "説明を追加"
 },
 "nplurals=1; plural=0;");
