@@ -11,21 +11,26 @@ OC.L10N.register(
     "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
     "Nextcloud Text" : "Nextcloud Text",
     "text document" : "document tèxt",
+    "File not found" : "Fichièr pas trobat",
     "Readme" : "Readme",
     "Text" : "Tèxt",
     "📝 Collaborative document editing" : "📝 Edicion collaborativa de document",
+    "Translate" : "Translate",
     "Use current version" : "Utilizar la version actuala",
     "Use the saved version" : "Utilizar la version salvada",
+    "Reload" : "Recargar",
     "Reconnect" : "Se reconnectar",
-    "The document has been changed outside of the editor. The changes cannot be applied." : "Lo document es estat modificar defòra de l’editor. Se pòdon pas aplicar las modificacions.",
     "Edit guest name" : "Modificar lo nom de convidat",
     "Guest" : "Convidat",
     "Save guest name" : "Enregistrar lo nom de convidat",
+    "Insert an attachment" : "Inserir una pèça junta",
     "guest" : "convidat",
-    "Show author colors" : "Afichar las colors dels utilizaires",
+    "Last saved" : "Darrièra salvagarda",
     "Offline" : "Fòra linha",
     "Saving …" : "Enregistrament...",
     "Saved" : "Enregistrat",
+    "Last saved {lastSave}" : "Darrièra salvagarda {lastSave}",
+    "The document has been changed outside of the editor. The changes cannot be applied." : "Lo document es estat modificar defòra de l’editor. Se pòdon pas aplicar las modificacions.",
     "Unsaved changes" : "Modificacions pas enregistradas",
     "Keyboard shortcuts" : "Acorchis de clavièr",
     "Bold" : "Gras",
@@ -36,28 +41,34 @@ OC.L10N.register(
     "Ordered list" : "Lista ordenada",
     "Blockquote" : "Citacion",
     "Code block" : "Còdi",
-    "Translate" : "Translate",
+    "Link" : "Ligam",
+    "Insert emoji" : "Inserir emoji",
     "Undo" : "Anullar",
     "Redo" : "Refar",
+    "Edit link" : "Modificar lo ligam",
+    "Save changes" : "Salvar modificacions",
+    "Cancel" : "Anullar",
+    "URL" : "URL",
+    "Remaining actions" : "Mai d’accions",
+    "Select language" : "Causir lenga",
+    "to" : "a",
+    "Edit" : "Modificar",
+    "Source code" : "Còdi font",
+    "Delete this table" : "Suprimir aqueste tablèu",
     "Headings" : "Títols",
     "Heading 2" : "Títol 2",
     "Heading 3" : "Títol 3",
     "Heading 4" : "Títol 4",
     "Heading 5" : "Títol 5",
+    "Table" : "Tablèu",
+    "Details" : "Per lo Menut",
+    "Insert link" : "Inserir un ligam",
+    "Insert attachment" : "Inserir una pèça junta",
+    "Command" : "Comanda",
+    "Show author colors" : "Afichar las colors dels utilizaires",
     "Info" : "Info",
     "Success" : "Succès",
     "Warning" : "Avertiment",
-    "Insert emoji" : "Inserir emoji",
-    "Command" : "Comanda",
-    "Add notes, lists or links …" : "Apondre nòtas, listas o ligamas…",
-    "Edit" : "Modificar",
-    "Last saved {lastSaved}" : "Darrièr enregistrament {lastSaved}",
-    "Enter your name so other users can see who is editing" : "Picatz vòstre nom per que los autres utilizaires vejan qual es a modificar",
-    "Insert an image" : "Inserir un imatge",
-    "Link file" : "Ligam fichièr",
-    "Remove Link" : "Suprimir ligam",
-    "ToDo list" : "Lista a far",
-    "Emoji picker" : "Selector emoji",
-    "Insert image" : "Inserir imatge"
+    "Add notes, lists or links …" : "Apondre nòtas, listas o ligams…"
 },
 "nplurals=2; plural=(n > 1);");
