@@ -19,7 +19,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
-    "Education Edition" : "Kennsluútgáfa",
     "Enterprise bundle" : "Fyrirtækjavöndull",
     "Groupware bundle" : "Hópvinnsluvöndull",
     "Hub bundle" : "Tengivöndull",
@@ -76,14 +75,12 @@ OC.L10N.register(
     "seconds ago" : "sekúndum síðan",
     "Empty file" : "Tóm skrá",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Eining með auðkenni: %s er ekki til. Virkjaðu hana í forritastillingum eða hafðu samband við kerfisstjóra.",
+    "Dot files are not allowed" : "Skrár með punkti eru ekki leyfðar",
     "File already exists" : "Skrá er þegar til",
     "Invalid path" : "Ógild slóð",
     "Failed to create file from template" : "Mistókst að búa til skrá út frá sniðmáti",
     "Templates" : "Sniðmát",
-    "File name is a reserved word" : "Skráarheiti er þegar frátekið orð",
-    "File name contains at least one invalid character" : "Skráarheitið inniheldur að minnsta kosti einn ógildan staf",
-    "File name is too long" : "Skráarheiti er of langt",
-    "Dot files are not allowed" : "Skrár með punkti eru ekki leyfðar",
+    "Filename contains at least one invalid character" : "Skráarheitið inniheldur að minnsta kosti einn ógildan staf",
     "Empty filename is not allowed" : "Autt skráarheiti er ekki leyft.",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Ekki er hægt að setja upp \"%s\" forritið vegna þess að ekki var hægt að lesa appinfo-skrána.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Ekki var hægt að setja upp forritið \"%s\" vegna þess að það er ekki samhæft þessari útgáfu vefþjónsins.",
@@ -95,7 +92,7 @@ OC.L10N.register(
     "Administration settings" : "Stillingar stjórnunar",
     "Settings" : "Stillingar",
     "Log out" : "Skrá út",
-    "Users" : "Notendur",
+    "Accounts" : "Notandaaðgangar",
     "Email" : "Tölvupóstur",
     "Mail %s" : "Póstur %s",
     "Fediverse" : "Skýjasamband",
@@ -127,11 +124,15 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Deilingarbakendinn %s verður að vera settur upp fyrir viðmótið OCP\\Share_Backend",
     "Sharing backend %s not found" : "Deilingarbakendinn %s fannst ekki",
     "Sharing backend for %s not found" : "Deilingarbakendi fyrir %s fannst ekki",
+    "%1$s shared »%2$s« with you" : "%1$s deildi »%2$s« með þér",
+    "%1$s shared »%2$s« with you." : "%1$s deildi »%2$s« með þér.",
+    "Click the button below to open it." : "Smelltu á hnappinn hér fyrir neðan til að opna það.",
+    "Open »%s«" : "Opna »%s«",
+    "%1$s via %2$s" : "%1$s með %2$s",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s deildi »%2$s« með þér og vill bæta við:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s deildi »%2$s« með þér og vill bæta við",
     "»%s« added a note to a file shared with you" : "»%s« bætti minnispunkti við skrá sem deilt er með þér",
-    "Open »%s«" : "Opna »%s«",
-    "%1$s via %2$s" : "%1$s með %2$s",
+    "Unknown share type" : "Óþekkt tegund sameignar",
     "You are not allowed to share %s" : "Þú hefur ekki heimild til að deila %s",
     "Cannot increase permissions of %s" : "Get ekki aukið aðgangsheimildir %s",
     "Files cannot be shared with delete permissions" : "Ekki er hægt að deila skrá með eyða-heimildum",
@@ -139,9 +140,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Gildistíminn er þegar runninn út",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ekki er hægt að setja lokadagsetningu meira en %n dag fram í tímann","Ekki er hægt að setja lokadagsetningu meira en %n daga fram í tímann"],
     "Sharing is only allowed with group members" : "Deiling er aðeins leyfð með meðlimum hópsins",
-    "%1$s shared »%2$s« with you" : "%1$s deildi »%2$s« með þér",
-    "%1$s shared »%2$s« with you." : "%1$s deildi »%2$s« með þér.",
-    "Click the button below to open it." : "Smelltu á hnappinn hér fyrir neðan til að opna það.",
     "The requested share does not exist anymore" : "Umbeðin sameign er ekki lengur til",
     "The requested share comes from a disabled user" : "Umbeðin sameign kemur frá notanda sem er óvirkur",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Notandinn var ekki búinn til þar sem takmörkum á fjölda notenda var náð. Skoðaðu tilkynningarnar þínar til að sjá meira.",
@@ -195,8 +193,6 @@ OC.L10N.register(
     "Login canceled by app" : "Forrit hætti við innskráningu",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Ekki var hægt að setja upp \"%1$s\" forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar: %2$s",
     "a safe home for all your data" : "öruggur staður fyrir öll gögnin þín",
-    "File is currently busy, please try again later" : "Skráin er upptekin í augnablikinu, reyndu aftur síðar",
-    "Cannot download file" : "Get ekki sótt skrá",
     "Application is not enabled" : "Forrit ekki virkt",
     "Authentication error" : "Villa við auðkenningu",
     "Token expired. Please reload page." : "Kenniteikn er útrunnið. Þú ættir að hlaða síðunni aftur inn.",
@@ -227,7 +223,6 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Gagnamappan þín verður að vera með algilda slóð.",
     "Check the value of \"datadirectory\" in your configuration." : "Athugaðu gildi \"datadirectory\" í uppsetningunni þinni.",
     "Your data directory is invalid." : "Gagnamappan þín er ógild.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Gakktu úr skugga um að til staðar sé skrá með heitinu \".ocdata\" í rót gagnageymslunnar.",
     "Action \"%s\" not supported or implemented." : "Aðgerðin \"%s\" er ekki studd eða útfærð.",
     "Authentication failed, wrong token or provider ID given" : "Auðkenning mistókst, uppgefið rangt teikn eða auðkenni þjónustuveitu",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Breytur vantar til að geta lokið beiðninni. Breytur sem vantar: \"%s\"",
@@ -239,19 +234,27 @@ OC.L10N.register(
     "Storage connection error. %s" : "Villa í tengingu við gagnageymslu. %s",
     "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
     "Storage connection timeout. %s" : "Gagnageymsla féll á tíma. %s",
+    "Generates a possible headline for a text." : "Útbýr mögulega fyrirsögn fyrir texta.",
+    "Summarize" : "Gera samantekt",
+    "Summary" : "Samantekt",
+    "Extract topics" : "Taka út efnisflokka",
+    "Translate" : "Þýða",
+    "Target language" : "Marktungumál:",
+    "Result" : "Niðurstöður",
     "Free prompt" : "Frjáls kvaðning",
     "Runs an arbitrary prompt through the language model." : "Keyrir óreglulega kvaðningu (prompt) í gegnum tungumálslíkanið.",
     "Generate headline" : "Útbúa fyrirsögn",
-    "Generates a possible headline for a text." : "Útbýr mögulega fyrirsögn fyrir texta.",
-    "Summarize" : "Gera samantekt",
     "Summarizes text by reducing its length without losing key information." : "Tekur saman aðalatriði texta með því að stytta hann án þess að tapa mikilvægustu upplýsingum.",
-    "Extract topics" : "Taka út efnisflokka",
     "Extracts topics from a text and outputs them separated by commas." : "Greinir efnisflokka úr texta og aðskilur þá með kommum.",
-    "404" : "404",
+    "Education Edition" : "Kennsluútgáfa",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Innskráður notandi verður að vera kerfisstjóri eða undirstjórnandi eða hafa fengið sérstaka aðgangsheimild fyrir þessa stillingu",
     "Logged in user must be an admin or sub admin" : "Innskráður notandi verður að vera kerfisstjóri eða undirstjórnandi",
     "Logged in user must be an admin" : "Innskráður notandi verður að vera stjórnandi",
+    "File name is a reserved word" : "Skráarheiti er þegar frátekið orð",
+    "File name contains at least one invalid character" : "Skráarheitið inniheldur að minnsta kosti einn ógildan staf",
+    "File name is too long" : "Skráarheiti er of langt",
     "Help" : "Hjálp",
+    "Users" : "Notendur",
     "Unknown user" : "Óþekktur notandi",
     "Enter the database username and name for %s" : "Settu inn notandanafn og nafn í gagnagrunni fyrir %s",
     "Enter the database username for %s" : "Settu inn notandanafn í gagnagrunni fyrir %s",
@@ -268,9 +271,10 @@ OC.L10N.register(
     "Username must not consist of dots only" : "Notandanafn má ekki einungis samanstanda af punktum",
     "Username is invalid because files already exist for this user" : "Notandanafnið er ógilt vegna þess að þegar eru fyrir hendi skrár sem tilheyra þessum notanda",
     "User disabled" : "Notandi óvirkur",
-    "PostgreSQL >= 9 required." : "Krefst PostgreSQL >= 9.",
-    "Please upgrade your database version." : "Uppfærðu útgáfu gagnagrunnsins.",
+    "File is currently busy, please try again later" : "Skráin er upptekin í augnablikinu, reyndu aftur síðar",
+    "Cannot download file" : "Get ekki sótt skrá",
     "Your data directory is readable by other users." : "Gagnamappn þín er lesanleg fyrir aðra notendur.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endilega breyttu heimildunum í 0770 svo að aðrir notendur geti ekki listað upp innihald hennar."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endilega breyttu heimildunum í 0770 svo að aðrir notendur geti ekki listað upp innihald hennar.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Gakktu úr skugga um að til staðar sé skrá með heitinu \".ocdata\" í rót gagnageymslunnar."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
