@@ -19,7 +19,7 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s ve %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ve %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ve %5$s",
-    "Education Edition" : "Eğitim sürümü",
+    "Education bundle" : "Eğitim paketi",
     "Enterprise bundle" : "Kurumsal paket",
     "Groupware bundle" : "Grup çalışması paketi",
     "Hub bundle" : "Toplayıcı paketi",
@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Sunucu %s ya da daha sonraki bir sürüm olmalıdır.",
     "Server version %s or lower is required." : "Sunucu %s ya da daha önceki bir sürüm olmalıdır.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış hesap bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
+    "Your current IP address doesn’t allow you to perform admin actions" : "Geçerli IP adresiniz yönetici işlemleri yapmanıza izin vermiyor",
     "Logged in account must be an admin or sub admin" : "Oturum açmış hesap bir yönetici ya da alt yönetici olmalıdır",
     "Logged in account must be an admin" : "Oturum açmış hesap bir yönetici olmalıdır",
     "Wiping of device %s has started" : "%s aygıtının silinmesine başlandı",
@@ -79,27 +80,35 @@ OC.L10N.register(
     "in a few seconds" : "bir kaç saniye içinde",
     "seconds ago" : "saniyeler önce",
     "Empty file" : "Dosya boş",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s kimlikli modül bulunamadı. Lütfen uygulamalarınız içinden modülü etkinleştirin ya da BT yöneticinizle görüşün.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s kimlikli modül bulunamadı. Lütfen uygulamalarınız içinden modülü kullanıma alın ya da BT yöneticiniz ile görüşün.",
+    "Dot files are not allowed" : "Nokta dosyalarına izin verilmiyor",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" dosya ya da klasör adı olarak kullanılamaz.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" dosya ya da klasör adı ön eki olarak kullanılamaz.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" bir dosya ya da klasör adında kullanılamaz.",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\" dosya türüne izin verilmiyor.",
+    "Filenames must not end with \"%1$s\"." : "Dosya adları \"%1$s\" ile bitemez.",
+    "Invalid parent path" : "Üst yol geçersiz",
     "File already exists" : "Dosya zaten var",
     "Invalid path" : "Yol geçersiz",
     "Failed to create file from template" : "Kalıptan dosya oluşturulamadı",
     "Templates" : "Kalıplar",
-    "File name is a reserved word" : "Bu dosya adı sistem kullanıma ayrılmıştır",
-    "File name contains at least one invalid character" : "Dosya adında en az bir geçersiz karakter var",
-    "File name is too long" : "Dosya adı çok uzun",
-    "Dot files are not allowed" : "Nokta dosyalarına izin verilmiyor",
+    "Path contains invalid segments" : "Yolda geçersiz bölümler var",
+    "Filename is a reserved word" : "Dosya adı sistem kullanımına ayrılmış bir sözcük",
+    "Filename contains at least one invalid character" : "Dosya adında en az bir geçersiz karakter var",
+    "Filename is too long" : "Dosya adı çok uzun",
     "Empty filename is not allowed" : "Boş dosya adına izin verilmiyor",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfo dosyası okunamadığından \"%s\" uygulaması kurulamaz.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" uygulaması sunucu sürümüyle uyumlu olmadığından kurulamaz.",
     "__language_name__" : "Türkçe",
     "This is an automatically sent email, please do not reply." : "Bu ileti otomatik olarak gönderildiğinden lütfen yanıtlamayın.",
+    "Help & privacy" : "Yardım ve gizlilik",
     "Appearance and accessibility" : "Görünüm ve erişilebilirlik",
     "Apps" : "Uygulamalar",
     "Personal settings" : "Kişisel ayarlar",
     "Administration settings" : "Yönetim ayarları",
     "Settings" : "Ayarlar",
     "Log out" : "Oturumu kapat",
-    "Users" : "Kullanıcılar",
+    "Accounts" : "Hesaplar",
     "Email" : "E-posta",
     "Mail %s" : "E-posta gönder: %s",
     "Fediverse" : "Fediverse",
@@ -117,6 +126,7 @@ OC.L10N.register(
     "Headline" : "Başlık",
     "Organisation" : "Kuruluş",
     "Role" : "Pozisyon",
+    "Pronouns" : "Hitaplar",
     "Unknown account" : "Hesap bilinmiyor",
     "Additional settings" : "Ek ayarlar",
     "Enter the database Login and name for %s" : "%s için veri tabanı adını ve kullanıcı adını yazın",
@@ -138,26 +148,62 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Paylaşım arka ucu %s OCP\\Share_Backend arayüzünü desteklemeli",
     "Sharing backend %s not found" : "%s paylaşım arka ucu bulunamadı",
     "Sharing backend for %s not found" : "%s için paylaşım arka ucu bulunamadı",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s sizinle »%2$s« ögesini paylaştı ve eklemenizi istiyor:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s sizinle »%2$s« ögesini paylaştı ve eklemenizi istiyor",
-    "»%s« added a note to a file shared with you" : "»%s« sizinle paylaştığı bir dosyaya bir not ekledi",
-    "Open »%s«" : "»%s« aç",
-    "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
-    "You are not allowed to share %s" : "%s ögesini paylaşma izniniz yok",
-    "Cannot increase permissions of %s" : "%s izinleri yükseltilemedi",
-    "Files cannot be shared with delete permissions" : "Silme izni ile dosya paylaşılamaz",
-    "Files cannot be shared with create permissions" : "Ekleme izni ile dosya paylaşılamaz",
-    "Expiration date is in the past" : "Geçerlilik sonu tarihi geçmişte",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz","Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz"],
-    "Sharing is only allowed with group members" : "Paylaşım yalnızca grup üyeleri ile yapılabilir",
-    "Sharing %s failed, because this item is already shared with the account %s" : "%s paylaşılamadı. Bu öge zaten %s hesabı ile paylaşılmış",
     "%1$s shared »%2$s« with you" : "%1$s, sizinle »%2$s« ögesini paylaştı",
     "%1$s shared »%2$s« with you." : "%1$s, sizinle »%2$s« ögesini paylaştı.",
     "Click the button below to open it." : "Açmak için aşağıdaki düğmeye tıklayın.",
+    "Open »%s«" : "»%s« aç",
+    "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s sizinle »%2$s« ögesini paylaştı ve eklemenizi istiyor:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s sizinle »%2$s« ögesini paylaştı ve eklemenizi istiyor",
+    "»%s« added a note to a file shared with you" : "»%s« sizinle paylaştığı bir dosyaya bir not ekledi",
+    "Passwords are enforced for link and mail shares" : "Bağlantı ve e-posta paylaşımları için parolalar zorunludur",
+    "Share recipient is not a valid user" : "Paylaşım alıcısı geçerli bir kullanıcı değil",
+    "Share recipient is not a valid group" : "Paylaşım alıcısı geçerli bir grup değil",
+    "Share recipient should be empty" : "Paylaşım alıcısı boş olmalı",
+    "Share recipient should not be empty" : "Paylaşım alıcısı boş olmamalı",
+    "Share recipient is not a valid circle" : "Paylaşım alıcısı geçerli bir çevre değil",
+    "Unknown share type" : "Paylaşım türü bilinmiyor",
+    "Share initiator must be set" : "Paylaşımı başlatan ayarlanmalıdır",
+    "Cannot share with yourself" : "Kendinizle paylaşamazsınız",
+    "Shared path must be set" : "Paylaşılan yol ayarlanmalıdır",
+    "Shared path must be either a file or a folder" : "Paylaşılan yol bir dosya ya da klasör olmalıdır",
+    "You cannot share your root folder" : "Kök klasörünüzü paylaşamazsınız",
+    "You are not allowed to share %s" : "%s ögesini paylaşma izniniz yok",
+    "Valid permissions are required for sharing" : "Paylaşım için geçerli izinler olmalıdır",
+    "Cannot increase permissions of %s" : "%s izinleri yükseltilemedi",
+    "Shares need at least read permissions" : "Paylaşımların en azından okuma izinleri olmalıdır",
+    "Files cannot be shared with delete permissions" : "Silme izni ile dosya paylaşılamaz",
+    "Files cannot be shared with create permissions" : "Ekleme izni ile dosya paylaşılamaz",
+    "Expiration date is in the past" : "Geçerlilik sonu tarihi geçmişte",
+    "Expiration date is enforced" : "Geçerlilik sonu tarihi dayatılıyor",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz","Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz"],
+    "Sharing is only allowed with group members" : "Paylaşım yalnızca grup üyeleri ile yapılabilir",
+    "Sharing %s failed, because this item is already shared with the account %s" : "%s paylaşılamadı. Bu öge zaten %s hesabı ile paylaşılmış",
+    "Group sharing is now allowed" : "Artık grup paylaşımına izin veriliyor",
+    "Sharing is only allowed within your own groups" : "Paylaşım yalnızca kendi gruplarınız ile yapılabilir",
+    "Path is already shared with this group" : "Bu yol bu grup ile zaten paylaşılmış",
+    "Link sharing is not allowed" : "Bağlantı paylaşımına izin verilmiyor",
+    "Public upload is not allowed" : "Herkese açık yüklemeye izin verilmiyor",
+    "Path contains files shared with you" : "Yolda sizinle paylaşılmış dosyalar var",
+    "Sharing is disabled" : "Paylaşım kullanımdan kaldırılmış",
+    "Sharing is disabled for you" : "Paylaşım sizin için kullanımdan kaldırılmış",
+    "Cannot share with the share owner" : "Paylaşımı sahibi ile paylaşamazsınız",
+    "Share does not have a full ID" : "Paylaşımın tam kimliği yok",
+    "Cannot change share type" : "Paylaşım türü değiştirilemez",
+    "Can only update recipient on user shares" : "Yalnızca kullanıcı paylaşımlarındaki alıcıyı güncelleyebilir",
+    "Cannot enable sending the password by Talk with an empty password" : "Boş bir parola ile Sohbet uygulaması ile parola gönderme özelliği kullanıma alınamaz",
+    "Cannot enable sending the password by Talk without setting a new password" : "Yeni bir parola ayarlanmadan Sohbet uygulaması ile parola gönderme özelliği kullanıma alınamaz",
+    "Cannot disable sending the password by Talk without setting a new password" : "Yeni bir parola ayarlanmadan Sohbet uygulaması ile parola gönderme kullanımdan kaldırılamaz",
+    "Share provider does not support accepting" : "Paylaşım hizmeti sağlayıcısı kabul etmeyi desteklemiyor",
+    "Cannot change target of link share" : "Bağlantı paylaşımının hedefi değiştirilemedi",
+    "Invalid share recipient" : "Paylaşım alıcısı geçersiz",
+    "Group \"%s\" does not exist" : "\"%s\" grubu bulunamadı",
     "The requested share does not exist anymore" : "Erişilmek istenilen paylaşım artık yok",
-    "The requested share comes from a disabled user" : "Erişilmek istenilen paylaşım devre dışı bırakılmış bir kullanıcıdan geliyor",
+    "The requested share comes from a disabled user" : "Erişilmek istenilen paylaşım kullanımdan kaldırılmış bir kullanıcıdan geliyor",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Kullanıcı sayısı sınırına ulaşıldığından kullanıcı eklenemedi. Ayrıntılı bilgi almak için bildirimlerinize bakın.",
     "Could not find category \"%s\"" : "\"%s\" kategorisi bulunamadı",
+    "Input text" : "Giriş metni",
+    "The input text" : "Giriş metni",
     "Sunday" : "Pazar",
     "Monday" : "Pazartesi",
     "Tuesday" : "Salı",
@@ -211,13 +257,11 @@ OC.L10N.register(
     "Login contains whitespace at the beginning or at the end" : "Kullanıcı adının başında ya da sonunda boşluk var",
     "Login must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
     "Login is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
-    "Account disabled" : "Hesap devre dışı",
+    "Account disabled" : "Hesap kullanımdan kaldırılmış",
     "Login canceled by app" : "Oturum açma uygulama tarafından iptal edildi",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" uygulaması, şu gereklilikler sağlanmadığı için kurulamıyor: %2$s",
     "a safe home for all your data" : "verileriniz için güvenli bir barınak",
-    "File is currently busy, please try again later" : "Dosya şu anda meşgul. Lütfen bir süre sonra yeniden deneyin",
-    "Cannot download file" : "Dosya indirilemedi",
-    "Application is not enabled" : "Uygulama etkinleştirilmemiş",
+    "Application is not enabled" : "Uygulama kullanıma alınmamış",
     "Authentication error" : "Kimlik doğrulama sorunu",
     "Token expired. Please reload page." : "Kodun geçerlilik süresi dolmuş. Lütfen sayfayı yenileyin.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Herhangi bir veri tabanı sürücüsü (sqlite, mysql ya da postgresql) kurulmamış.",
@@ -225,7 +269,7 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Bu sorun genellikle, site sunucusuna config klasörüne yazma izni verilerek çözülebilir. %s bölümüne bakın",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ya da config.php dosyasının salt okunur olarak kalmasını istiyorsanız içindeki \"config_is_read_only\" seçeneğini true olarak ayarlayın. %s bölümüne bakabilirsiniz",
     "Cannot write into \"apps\" directory." : "\"apps\" klasörüne yazılamadı.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, site sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından uygulama mağazası devre dışı bırakılarak çözülebilir.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, site sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından uygulama mağazası kullanımdan kaldırılarak çözülebilir.",
     "Cannot create \"data\" directory." : "\"data\" klasörü oluşturulamadı",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Bu sorun genellikle, site sunucusuna kök klasöre yazma izni verilerek çözülebilir. %s bölümüne bakın",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "İzinler genellikle, site sunucusuna kök klasöre yazma izni verilerek düzeltilebilir. %s bölümüne bakın.",
@@ -233,7 +277,7 @@ OC.L10N.register(
     "Setting locale to %s failed." : "Dil %s olarak ayarlanamadı.",
     "Please install one of these locales on your system and restart your web server." : "Lütfen bu dillerden birini sisteminize kurun ve site sunucunuzu yeniden başlatın.",
     "PHP module %s not installed." : "PHP %s modülü kurulmamış.",
-    "Please ask your server administrator to install the module." : "Lütfen modülü kurması için BT yöneticinizle görüşün.",
+    "Please ask your server administrator to install the module." : "Lütfen modülü kurması için BT yöneticiniz ile görüşün.",
     "PHP setting \"%s\" is not set to \"%s\"." : "\"%s\" PHP ayarı \"%s\" olarak ayarlanmamış.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini dosyasında bu ayar yapıldığında Nextcloud yeniden çalışır",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>, beklenen <code>0</code> değeri yerine <code>%s</code> olarak ayarlanmış.",
@@ -241,15 +285,15 @@ OC.L10N.register(
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP girintili doc bloklarını ayıklamak üzere yapılandırılmış gibi görünüyor. Bu durum bazı çekirdek uygulamalarına erişilmesini engelleyecek.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu sorun genellikle Zend OPcache ya da eAccelerator gibi bir ön bellek/hızlandırıcı nedeniyle ortaya çıkar.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modülleri kurulmuş, ancak hala eksik olarak mı görünüyor?",
-    "Please ask your server administrator to restart the web server." : "Lütfen site sunucusunu yeniden başlatması için BT yöneticinizle görüşün.",
+    "Please ask your server administrator to restart the web server." : "Lütfen site sunucusunu yeniden başlatması için BT yöneticiniz ile görüşün.",
     "The required %s config variable is not configured in the config.php file." : "Gereken %s yapılandırma değişkeni config.php dosyasında ayarlanmamış.",
-    "Please ask your server administrator to check the Nextcloud configuration." : "Lütfen Nextcloud yapılandırmasını denetlemesi için BT yöneticinizle görüşün.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Lütfen Nextcloud yapılandırmasını denetlemesi için BT yöneticiniz ile görüşün.",
     "Your data directory is readable by other people." : "Veri klasörünüz diğer kişiler tarafından okunabilir.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kişilerin klasörü görebilmesini sağlayın.",
     "Your data directory must be an absolute path." : "Veri klasörünüz mutlak bir yol olmalıdır.",
     "Check the value of \"datadirectory\" in your configuration." : "Yapılandırmanızdaki \"datadirectory\" değerini denetleyin.",
     "Your data directory is invalid." : "Veri klasörünüz geçersiz.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Veri klasörü kökünde \".ocdata\" adında bir dosya bulunduğundan emin olun.",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Veri klasörü kökünde \"%1$s\" adında bir dosya bulunduğundan emin olun. İçeriğinde şu bulunmalıdır: \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "\"%s\" işlemi desteklenmiyor ya da henüz kullanılamıyor.",
     "Authentication failed, wrong token or provider ID given" : "Kimlik doğrulanamadı. Belirtilen kod ya da hizmet sağlayıcı kimliği hatalı",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "İsteğin tamamlanması için gerekli parametreler eksik: \"%s\"",
@@ -261,19 +305,102 @@ OC.L10N.register(
     "Storage connection error. %s" : "Depolama bağlantısı sorunu. %s",
     "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
     "Storage connection timeout. %s" : "Depolama bağlantısı zaman aşımı. %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Bu denetimi çalıştırabilmek için site sunucunuzun kendisine bağlanabildiğinden emin olmanız gerekir. Bu nedenle, `trusted_domains` ya da `overwrite.cli.url` değerlerinden en az birini çözümleyebilmeli ve bunlara bağlanabilmelidir. Bu sorun, sunucu tarafındaki bir DNS uyumsuzluğunun veya giden güvenlik duvarı kuralının sonucu olabilir.",
+    "Transcribe audio" : "Sesten yazıya dönüştür.",
+    "Transcribe the things said in an audio" : "Bir sestekileri yazıya dönüştür",
+    "Audio input" : "Ses girişi",
+    "The audio to transcribe" : "Yazıya dönüştürülecek ses",
+    "Transcription" : "Yazıya dönüştürme",
+    "The transcribed text" : "Dönüştürülen yazı",
+    "Context write" : "Bağlam yazma",
+    "Writes text in a given style based on the provided source material." : "Sağlanan kaynak materyale göre belirli bir tarzda metin yazar.",
+    "Writing style" : "Yazma tarzı",
+    "Demonstrate a writing style that you would like to immitate" : "Taklit etmek isteyeceğiniz bir yazım tarzını gösterin",
+    "Source material" : "Kaynak materyal",
+    "The content that would like to be rewritten in the new writing style" : "Yeni yazım tarzında yeniden yazılması istenen içerik",
+    "Generated text" : "Oluşturulan metin",
+    "The generated text with content from the source material in the given style" : "Kaynak materyal içeriği ile belirtilen tarzda oluşturulan metin",
+    "Emoji generator" : "Duygu ifadesi oluşturma",
+    "Takes text and generates a representative emoji for it." : "Metni alır ve onu temsil eden bir duygu ifadesi oluşturur.",
+    "The text to generate an emoji for" : "Duygu ifadesi oluşturulacak metin",
+    "Generated emoji" : "Oluşturulan duygu ifadesi",
+    "The generated emoji based on the input text" : "Giriş metnine göre oluşturulan duygu ifadesi",
+    "Generate image" : "Görsel oluştur",
+    "Generate an image from a text prompt" : "Bir yazıdan bir duygu ifadesi oluştur",
+    "Prompt" : "Soru",
+    "Describe the image you want to generate" : "Oluşturmak istediğiniz görseli tanımlayın",
+    "Number of images" : "Görsel sayısı",
+    "How many images to generate" : "Oluşturulacak görsel sayısı",
+    "Output images" : "Çıktı görselleri",
+    "The generated images" : "Oluşturulan görseller",
+    "Free text to text prompt" : "Ücretsiz yazıdan yazıya istemi",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Dil modeli ile bir yanıt döndüren isteğe bağlı bir bilgi istemi çalıştırır",
+    "Describe a task that you want the assistant to do or ask a question" : "Yardımcının yapmasını istediğiniz bir görevi tanımlayın ya da bir soru sorun",
+    "Generated reply" : "Oluşturulan yanıt",
+    "The generated text from the assistant" : "Yardımcının oluşturduğu metin",
+    "Chat" : "Sohbet",
+    "Chat with the assistant" : "Yardımcı ile sohbet et",
+    "System prompt" : "Sistem istemi",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Sohbet sırasında yardımcının uyması gereken kuralları ve varsayımları tanımlayın.",
+    "Chat message" : "Sohbet iletisi",
+    "Chat history" : "Sohbet geçmişi",
+    "The history of chat messages before the current message, starting with a message by the user" : "Kullanıcının iletisiyle başlayarak, geçerli iletiden önceki sohbet iletilerinin geçmişi",
+    "Response message" : "Yanıt iletisi",
+    "The generated response as part of the conversation" : "Sohbetin parçası olarak oluşturulan yanıt",
+    "Formalize text" : "Metni resmileştir",
+    "Takes a text and makes it sound more formal" : "Bir metni alarak daha resmi dile dönüştürür",
+    "Write a text that you want the assistant to formalize" : "Yardımcının resmileştirmesini istediğiniz bir metin yazın",
+    "Formalized text" : "Resmileştirilmiş metin",
+    "The formalized text" : "Resmileştirilmiş metin",
+    "Generate a headline" : "Bir başlık oluştur",
+    "Generates a possible headline for a text." : "Bir metin için olası bir başlık oluşturur.",
+    "Original text" : "Özgün metin",
+    "The original text to generate a headline for" : "Başlık oluşturulacak metin",
+    "The generated headline" : "Oluşturulan başlık",
+    "Reformulate text" : "Metni yeniden düzenle",
+    "Takes a text and reformulates it" : "Bir metni alarak yeniden düzenler",
+    "Write a text that you want the assistant to reformulate" : "Yardımcının yeniden düzenlemesini istediğiniz bir metin yazın",
+    "Reformulated text" : "Yeniden düzenlenmiş metin",
+    "The reformulated text, written by the assistant" : "Yardımcı tarafından yazılan yeniden düzenlenmiş metin",
+    "Simplify text" : "Metni basitleştir",
+    "Takes a text and simplifies it" : "Bir metni alarak basitleştirir",
+    "Write a text that you want the assistant to simplify" : "Yardımcının basitleştirmesini istediğiniz bir metin yazın",
+    "Simplified text" : "Basitleştirilmiş metin",
+    "The simplified text" : "Basitleştirilmiş metin",
+    "Summarize" : "Özetlensin",
+    "Summarizes a text" : "Bir metni özetler",
+    "The original text to summarize" : "Özetlenecek özgün metin",
+    "Summary" : "Özet",
+    "The generated summary" : "Oluşturulan özet",
+    "Extract topics" : "Başlıklar ayıklansın",
+    "Extracts topics from a text and outputs them separated by commas" : "Bir metindeki konuları ayıklar ve bunları virgül ile ayırarak sıralar",
+    "The original text to extract topics from" : "Konuların ayıklanacağı özgün metin",
+    "Topics" : "Konular",
+    "The list of extracted topics" : "Ayıklanan konuların listesi",
+    "Translate" : "Çevir",
+    "Translate text from one language to another" : "Metni bir dilden diğerine çevir",
+    "Origin text" : "Kaynak metin",
+    "The text to translate" : "Çevrilecek metin",
+    "Origin language" : "Kaynak dil",
+    "The language of the origin text" : "Kaynak metnin dili",
+    "Target language" : "Hedef dil",
+    "The desired language to translate the origin text in" : "Kaynak metnin çevrilmesini istediğiniz dil",
+    "Result" : "Sonuç",
+    "The translated text" : "Çevrilmiş metin",
     "Free prompt" : "Ücretsiz bilgi istemi",
     "Runs an arbitrary prompt through the language model." : "Dil modeli ile isteğe bağlı bir bilgi istemi çalıştırır.",
     "Generate headline" : "Başlık oluşturulsun",
-    "Generates a possible headline for a text." : "Bir metin için olası bir başlık oluşturur.",
-    "Summarize" : "Özetlensin",
     "Summarizes text by reducing its length without losing key information." : "Temel içeriği kaybetmeden uzunluğunu kısaltarak metni özetler.",
-    "Extract topics" : "Başlıklar ayıklansın",
     "Extracts topics from a text and outputs them separated by commas." : "Bir metindeki konuları ayıklar ve bunları virgül ile ayırarak sıralar.",
-    "404" : "404",
+    "Education Edition" : "Eğitim sürümü",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış kullanıcı bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
     "Logged in user must be an admin or sub admin" : "Oturum açmış kullanıcı bir yönetici ya da alt yönetici olmalıdır",
     "Logged in user must be an admin" : "Oturum açmış kullanıcı bir yönetici olmalıdır",
+    "File name is a reserved word" : "Bu dosya adı sistem kullanıma ayrılmıştır",
+    "File name contains at least one invalid character" : "Dosya adında en az bir geçersiz karakter var",
+    "File name is too long" : "Dosya adı çok uzun",
     "Help" : "Yardım",
+    "Users" : "Kullanıcılar",
     "Unknown user" : "Kullanıcı bilinmiyor",
     "Enter the database username and name for %s" : "%s için veri tabanı adını ve kullanıcı adını yazın",
     "Enter the database username for %s" : "%s için veri tabanı kullanıcı adını yazın",
@@ -289,10 +416,11 @@ OC.L10N.register(
     "Username contains whitespace at the beginning or at the end" : "Kullanıcı adının başı ya da sonunda boşluk var",
     "Username must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
     "Username is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
-    "User disabled" : "Kullanıcı devre dışı",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 gerekli.",
-    "Please upgrade your database version." : "Lütfen veri tabanı sürümünüzü yükseltin.",
+    "User disabled" : "Kullanıcı kullanımdan kaldırılmış",
+    "File is currently busy, please try again later" : "Dosya şu anda meşgul. Lütfen bir süre sonra yeniden deneyin",
+    "Cannot download file" : "Dosya indirilemedi",
     "Your data directory is readable by other users." : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kullanıcıların klasörü görebilmesini sağlayın."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kullanıcıların klasörü görebilmesini sağlayın.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Veri klasörü kökünde \".ocdata\" adında bir dosya bulunduğundan emin olun."
 },
 "nplurals=2; plural=(n > 1);");
